@@ -721,3 +721,15 @@ if (parent->class == GAMGI_ENGINE_DIRECTION)
 gamgi_engine_unlink_atom (atom);
 return FALSE;
 }
+
+void gamgi_chem_atom_clean (gamgi_atom *atom)
+{
+gamgi_bond *bond;
+gamgi_dlist *dlist;
+
+for (dlist = atom->bond_start; dlist != NULL; dlist = dlist->next)
+  {
+  bond = GAMGI_CAST_BOND dlist->data;
+  bond->copy = NULL;
+  }
+}
