@@ -43,7 +43,7 @@ text_new->length = text->length;
 
 text_new->style = text->style;
 text_new->font = text->font;
-gamgi_mesa_text_font_increase (text_new);
+gamgi_mesa_text_font_increase (text_new, NULL);
 
 /****************************
  * position and orientation *
