@@ -358,3 +358,41 @@ for (dlist = start; dlist != NULL; dlist = dlist->before)
 
 return dlist_before;
 }
+
+gamgi_slist *gamgi_engine_slist_copy (gamgi_slist *start)
+{
+gamgi_slist *slist, *slist_new, *start_new;
+
+if (start == NULL) return NULL;
+
+start_new = gamgi_engine_slist_add_end (NULL);
+start_new->data = start->data;
+
+slist_new = start_new;
+for (slist = start->next; slist != NULL; slist = slist->next)
+  {
+  slist_new = gamgi_engine_slist_add_end (slist_new);
+  slist_new->data = slist->data;
+  }
+
+return start_new;
+}
+
+gamgi_dlist *gamgi_engine_dlist_copy (gamgi_dlist *start)
+{
+gamgi_dlist *dlist, *dlist_new, *start_new;
+
+if (start == NULL) return NULL;
+
+start_new = gamgi_engine_dlist_add_end (NULL);
+start_new->data = start->data;
+
+dlist_new = start_new;
+for (dlist = start->next; dlist != NULL; dlist = dlist->next)
+  {
+  dlist_new = gamgi_engine_dlist_add_end (dlist_new);
+  dlist_new->data = dlist->data;
+  }
+
+return start_new;
+}
