@@ -28,9 +28,10 @@
 void gamgi_engine_start_object (gamgi_object *object, int class)
 {
 strcpy (object->name, "");
-strcpy (object->type, "");
+strcpy (object->label, "");
 object->class = class;
 object->scale = GAMGI_MESA_SCALE;
+object->selection = NULL;
 object->dlist = NULL;
 object->object = NULL;
 }
@@ -223,8 +224,8 @@ direction->quaternion[3] = 1.0;
 
 direction->draw = NULL;
 direction->projection = NULL;
-
 direction->type = FALSE;
+
 direction->points = NULL;
 direction->loops = NULL;
 direction->n_points = 0;
@@ -282,8 +283,8 @@ plane->quaternion[3] = 1.0;
 
 plane->draw = NULL;
 plane->projection = NULL;
-
 plane->type = FALSE;
+
 plane->points = NULL;
 plane->loops = NULL;
 plane->n_points = 0;
@@ -311,6 +312,15 @@ group->object.number = gamgi_engine_number_group_get ();
  * initialise group *
  ********************/
 
+group->atom = -1;
+group->element = -1;
+group->number = 0;
+
+group->visible = 0.0;
+group->coplanar = 0.0;
+
+group->autonomy = FALSE;
+
 group->origin[0] = 0.0;
 group->origin[1] = 0.0;
 group->origin[2] = 0.0;
@@ -325,10 +335,10 @@ group->quaternion[2] = 0.0;
 group->quaternion[3] = 1.0;
 
 group->draw = NULL;
+group->type = FALSE;
 
 group->points = NULL;
 group->loops = NULL;
-
 group->n_points = 0;
 group->n_loops = 0;
 
@@ -416,10 +426,10 @@ cluster->n_points = 0;
 cluster->n_loops = 0;
 cluster->n_colors = 0;
 cluster->n_paints = 0;
-cluster->n_seeds = 0;
+cluster->n_dots = 0;
 
 cluster->faces = FALSE;
-cluster->seeds = FALSE;
+cluster->dots = FALSE;
 }
 
 /***** external function ****
@@ -728,15 +738,15 @@ window->dialog0 = NULL;
 window->dialog1 = NULL;
 window->help = NULL;
 
+window->area = NULL;
+window->history = NULL;
 window->layer = NULL;
 window->focus = NULL;
 
-window->history = NULL;
 window->action = FALSE;
+window->mode = FALSE;
 window->axes = FALSE;
-window->selection = FALSE;
-
-window->area = NULL;
+window->class = FALSE;
 
 window->top_flag = TRUE;
 window->medium_flag = TRUE;
@@ -757,7 +767,7 @@ window->demo_flag = 0;
  *                            *
  *  GAMGI_ENGINE_START_GAMGI  *
  *                            *
- * Initialise window objects. *
+ * Initialise gamgi object.   *
  *                            *
  ******************************/
 
