@@ -167,25 +167,29 @@ if (text_class->wired != GAMGI_IO_TEXT_WIRED)
 
 if (text_class->solid != GAMGI_IO_TEXT_SOLID)
   {
-  if (text_class->solid == GAMGI_IO_VERA_SANS)
+  if (text_class->solid == GAMGI_IO_DEJAVU_SANS)
     sprintf (string, "solid=\"sans\"");
-  else if (text_class->solid == GAMGI_IO_VERA_SANS_BOLD)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_SANS_BOLD)
     sprintf (string, "solid=\"sans_bold\"");
-  else if (text_class->solid == GAMGI_IO_VERA_SANS_ITALIC)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_SANS_ITALIC)
     sprintf (string, "solid=\"sans_italic\"");
-  else if (text_class->solid == GAMGI_IO_VERA_SANS_BOLD_ITALIC)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_SANS_BOLD_ITALIC)
     sprintf (string, "solid=\"sans_bold_italic\"");
-  else if (text_class->solid == GAMGI_IO_VERA_SERIF)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_SERIF)
     sprintf (string, "solid=\"serif\"");
-  else if (text_class->solid == GAMGI_IO_VERA_SERIF_BOLD)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_SERIF_BOLD)
     sprintf (string, "solid=\"serif_bold\"");
-  else if (text_class->solid == GAMGI_IO_VERA_MONO)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_SERIF_ITALIC)
+    sprintf (string, "solid=\"serif_italic\"");
+  else if (text_class->solid == GAMGI_IO_DEJAVU_SERIF_BOLD_ITALIC)
+    sprintf (string, "solid=\"serif_bold_italic\"");
+  else if (text_class->solid == GAMGI_IO_DEJAVU_MONO)
     sprintf (string, "solid=\"mono\"");
-  else if (text_class->solid == GAMGI_IO_VERA_MONO_BOLD)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_MONO_BOLD)
     sprintf (string, "solid=\"mono_bold\"");
-  else if (text_class->solid == GAMGI_IO_VERA_MONO_ITALIC)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_MONO_ITALIC)
     sprintf (string, "solid=\"mono_italic\"");
-  else if (text_class->solid == GAMGI_IO_VERA_MONO_BOLD_ITALIC)
+  else if (text_class->solid == GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC)
     sprintf (string, "solid=\"mono_bold_italic\"");
 
   gamgi_expat_export_element (fp, "<text", string,
@@ -464,11 +468,67 @@ if (fabs (atom_class->red[element] - red) > GAMGI_MATH_TOLERANCE
 void gamgi_expat_export_config_direction (gamgi_window *window, FILE *fp,
 int depth_parent, int *depth_last, gamgi_bool *output, gamgi_bool *error)
 {
+gamgi_direction_class *direction_class = gamgi->direction;
+char string[GAMGI_ENGINE_STRING];
+int column;
+
+/****************************
+ * red,green,blue (coupled) *
+ ****************************/
+
+if (fabs (direction_class->red - GAMGI_MESA_DIRECTION_R) > GAMGI_MATH_TOLERANCE
+|| fabs (direction_class->green - GAMGI_MESA_DIRECTION_G) > GAMGI_MATH_TOLERANCE
+|| fabs (direction_class->blue - GAMGI_MESA_DIRECTION_B) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "red=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, direction_class->red);
+  gamgi_expat_export_element (fp, "<direction", string,
+  depth_parent, depth_last, &column, output, error);
+
+  sprintf (string, "green=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, direction_class->green);
+  gamgi_expat_export_element (fp, "<direction", string,
+  depth_parent, depth_last, &column, output, error);
+
+  sprintf (string, "blue=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, direction_class->blue);
+  gamgi_expat_export_element (fp, "<direction", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
 }
 
 void gamgi_expat_export_config_plane (gamgi_window *window, FILE *fp,
 int depth_parent, int *depth_last, gamgi_bool *output, gamgi_bool *error)
 {
+gamgi_plane_class *plane_class = gamgi->plane;
+char string[GAMGI_ENGINE_STRING];
+int column;
+
+/****************************
+ * red,green,blue (coupled) *
+ ****************************/
+
+if (fabs (plane_class->red - GAMGI_MESA_PLANE_R) > GAMGI_MATH_TOLERANCE
+|| fabs (plane_class->green - GAMGI_MESA_PLANE_G) > GAMGI_MATH_TOLERANCE
+|| fabs (plane_class->blue - GAMGI_MESA_PLANE_B) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "red=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, plane_class->red);
+  gamgi_expat_export_element (fp, "<plane", string,
+  depth_parent, depth_last, &column, output, error);
+
+  sprintf (string, "green=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, plane_class->green);
+  gamgi_expat_export_element (fp, "<plane", string,
+  depth_parent, depth_last, &column, output, error);
+
+  sprintf (string, "blue=\"%.*f\"",
+  GAMGI_MATH_DECIMAL_COLOR, plane_class->blue);
+  gamgi_expat_export_element (fp, "<plane", string,
+  depth_parent, depth_last, &column, output, error);
+  }
+
 }
 
 void gamgi_expat_export_config_group (gamgi_window *window, FILE *fp,
