@@ -135,25 +135,29 @@ text->font != gamgi->text->wired)
 if (text->style == GAMGI_MESA_SOLID && 
 text->font != gamgi->text->solid)
   {
-  if (text->font == GAMGI_IO_VERA_SANS)
+  if (text->font == GAMGI_IO_DEJAVU_SANS)
     sprintf (string, "font=\"sans\"");
-  else if (text->font == GAMGI_IO_VERA_SANS_BOLD)
+  else if (text->font == GAMGI_IO_DEJAVU_SANS_BOLD)
     sprintf (string, "font=\"sans_bold\"");
-  else if (text->font == GAMGI_IO_VERA_SANS_ITALIC)
+  else if (text->font == GAMGI_IO_DEJAVU_SANS_ITALIC)
     sprintf (string, "font=\"sans_italic\"");
-  else if (text->font == GAMGI_IO_VERA_SANS_BOLD_ITALIC)
+  else if (text->font == GAMGI_IO_DEJAVU_SANS_BOLD_ITALIC)
     sprintf (string, "font=\"sans_bold_italic\"");
-  else if (text->font == GAMGI_IO_VERA_SERIF)
+  else if (text->font == GAMGI_IO_DEJAVU_SERIF)
     sprintf (string, "font=\"serif\"");
-  else if (text->font == GAMGI_IO_VERA_SERIF_BOLD)
+  else if (text->font == GAMGI_IO_DEJAVU_SERIF_BOLD)
     sprintf (string, "font=\"serif_bold\"");
-  else if (text->font == GAMGI_IO_VERA_MONO)
+  else if (text->font == GAMGI_IO_DEJAVU_SERIF_ITALIC)
+    sprintf (string, "font=\"serif_italic\"");
+  else if (text->font == GAMGI_IO_DEJAVU_SERIF_BOLD_ITALIC)
+    sprintf (string, "font=\"serif_bold_italic\"");
+  else if (text->font == GAMGI_IO_DEJAVU_MONO)
     sprintf (string, "font=\"mono\"");
-  else if (text->font == GAMGI_IO_VERA_MONO_BOLD)
+  else if (text->font == GAMGI_IO_DEJAVU_MONO_BOLD)
     sprintf (string, "font=\"mono_bold\"");
-  else if (text->font == GAMGI_IO_VERA_MONO_ITALIC)
+  else if (text->font == GAMGI_IO_DEJAVU_MONO_ITALIC)
     sprintf (string, "font=\"mono_italic\"");
-  else if (text->font == GAMGI_IO_VERA_MONO_BOLD_ITALIC)
+  else if (text->font == GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC)
     sprintf (string, "font=\"mono_bold_italic\"");
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
@@ -440,16 +444,16 @@ gamgi_expat_export_attribute (fp, string, depth, column, error);
 sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, atom->position[2]);
 gamgi_expat_export_attribute (fp, string, depth, column, error);
 
-/*****************************************
- * type, mass, radius, charge (optional) *
- *                                       *
- * radius, mass is -1 when undefined     *
- *****************************************/
+/******************************************
+ * label, mass, radius, charge (optional) *
+ *                                        *
+ * radius, mass is -1 when undefined      *
+ ******************************************/
 
 gamgi_io_token_lower (token, token+10);
-if (strcmp (atom->object.type, token+10) != 0)
+if (strcmp (atom->object.label, token+10) != 0)
   {
-  sprintf (string, "type=\"%s\"", atom->object.type);
+  sprintf (string, "label=\"%s\"", atom->object.label);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
@@ -745,9 +749,9 @@ if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
  * red,green,blue (optional, coupled) *
  **************************************/
 
-if (fabs (direction->red - GAMGI_MESA_DIRECTION_R) > GAMGI_MATH_TOLERANCE
-|| fabs (direction->green - GAMGI_MESA_DIRECTION_G) > GAMGI_MATH_TOLERANCE
-|| fabs (direction->blue - GAMGI_MESA_DIRECTION_B) > GAMGI_MATH_TOLERANCE)
+if (fabs (direction->red - gamgi->direction->red) > GAMGI_MATH_TOLERANCE
+|| fabs (direction->green - gamgi->direction->green) > GAMGI_MATH_TOLERANCE
+|| fabs (direction->blue - gamgi->direction->blue) > GAMGI_MATH_TOLERANCE)
   {
   sprintf (string, "red=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, direction->red);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
@@ -951,9 +955,9 @@ if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
  * red,green,blue (optional, coupled) *
  **************************************/
 
-if (fabs (plane->red - GAMGI_MESA_PLANE_R) > GAMGI_MATH_TOLERANCE
-|| fabs (plane->green - GAMGI_MESA_PLANE_G) > GAMGI_MATH_TOLERANCE
-|| fabs (plane->blue - GAMGI_MESA_PLANE_B) > GAMGI_MATH_TOLERANCE)
+if (fabs (plane->red - gamgi->plane->red) > GAMGI_MATH_TOLERANCE
+|| fabs (plane->green - gamgi->plane->green) > GAMGI_MATH_TOLERANCE
+|| fabs (plane->blue - gamgi->plane->blue) > GAMGI_MATH_TOLERANCE)
   {
   sprintf (string, "red=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, plane->red);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
@@ -1912,13 +1916,12 @@ if (GAMGI_EXPAT_ID_WINDOW == TRUE)
 gtk_window_get_position (GTK_WINDOW (window->window),
 &window->origin_x, &window->origin_y);
 
-if (window->origin_x != GAMGI_GTK_WINDOW_ORIGIN_X)
+if (window->origin_x != GAMGI_GTK_WINDOW_ORIGIN_X ||
+window->origin_y != GAMGI_GTK_WINDOW_ORIGIN_Y)
   {
   sprintf (string, "x=\"%d\"", window->origin_x);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
-if (window->origin_y != GAMGI_GTK_WINDOW_ORIGIN_Y)
-  {
+
   sprintf (string, "y=\"%d\"", window->origin_y);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
@@ -1935,14 +1938,12 @@ gtk_window_get_size (GTK_WINDOW (window->window), &window->width, &window->heigh
 if (window->width > 2 * gamgi->width) window->width = 2 * gamgi->width;
 if (window->height > 2 * gamgi->height) window->height = 2 * gamgi->height;
 
-if (window->width != GAMGI_GTK_WINDOW_WIDTH)
+if (window->width != GAMGI_GTK_WINDOW_WIDTH ||
+window->height != GAMGI_GTK_WINDOW_HEIGHT)
   {
   sprintf (string, "width=\"%d\"", window->width);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
 
-if (window->height != GAMGI_GTK_WINDOW_HEIGHT)
-  {
   sprintf (string, "height=\"%d\"", window->height);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
