@@ -1869,13 +1869,13 @@ while (i < gml->ref_used)
     gamgi_expat_import_plane (GAMGI_CAST_PLANE object,
     filename, fileline, gml) == FALSE) return FALSE;
 
-    /*************************************************
-     * each layer cannot have more than gml->lights  *
-     * lights, as defined by the Mesa/OpenGL library *
-     *************************************************/
+    /******************************************************
+     * each layer cannot have more than gamgi->max_lights *
+     * lights, as defined by the Mesa/OpenGL library      *
+     ******************************************************/
 
     if (object->class == GAMGI_ENGINE_LIGHT &&
-    gamgi->lights == (GAMGI_CAST_LAYER object->object)->light++)
+    gamgi->max_lights == (GAMGI_CAST_LAYER object->object)->light++)
       return gamgi_io_error_resources (filename, fileline, gml->ml.window);
     }
 
