@@ -24,6 +24,7 @@
 #include "gamgi_mesa_select.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_io_token.h"
+#include "gamgi_global_selection.h"
 
 static void static_clean (gamgi_window *window)
 {
@@ -65,15 +66,15 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-/********************* internal function ****************
- *                                                      *
- *                       STATIC_GLOBAL                  *
- *                                                      *
- * When the global button is on, disable the atom entry *
- * and reset dialog, otherwise, enable the atom entry.  *
+/******************* internal function *****************
+ *                                                     *
+ *                      STATIC_LIST                    *
+ *                                                     *
+ * When the List button is on, disable the atom entry  *
+ * and reset dialog, otherwise, enable the atom entry. *
  ********************************************************/
 
-static void static_global (GtkWidget *widget, void *data)
+static void static_list (GtkWidget *widget, void *data)
 {
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
@@ -81,7 +82,7 @@ GtkWidget *hbox;
 GtkWidget *button;
 
 hbox = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "hbox_atom");
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   {
@@ -102,14 +103,11 @@ else
   }
 }
 
-static void static_apply (gamgi_atom *atom, gamgi_window *window)
+static void static_apply (gamgi_atom *atom, int scope, gamgi_window *window)
 {
 gamgi_bond *bond;
 gamgi_object *parent;
 gamgi_dlist *dlist;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *combo;
-int row;
 
 /*****************************************************
  * Remove atom data according to Scope combo box:    *
@@ -120,14 +118,11 @@ int row;
  * 4) Child: Remove the child list of a given class; *
  *****************************************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
 /*****************************************
  * All: remove atom and all its contents *
  *****************************************/
 
-if (row == 0)
+if (scope == 0)
   {
   gamgi_chem_atom_unlink (atom);
   gamgi_engine_remove_atom (atom);
@@ -137,7 +132,7 @@ if (row == 0)
  * Container: link contents to atom parent and remove atom *
  ***********************************************************/
 
-if (row == 1)
+else if (scope == 1)
   {
   parent = atom->object.object;
   gamgi_engine_reparent_orbital (atom->orbital_start, parent);
@@ -150,7 +145,7 @@ if (row == 1)
  * Contents: remove all child objects in atom *
  **********************************************/
 
-if (row == 2)
+else if (scope == 2)
   {
   dlist = atom->bond_start;
   while (dlist != NULL)
@@ -180,7 +175,7 @@ if (row == 2)
  * Bond: remove bond list in atom *
  **********************************/
 
-if (row == 3)
+else if (scope == 3)
   {
   dlist = atom->bond_start;
   while (dlist != NULL)
@@ -196,7 +191,7 @@ if (row == 3)
  * Orbital: remove orbital list in atom *
  ****************************************/
 
-if (row == 4)
+else if (scope == 4)
   {
   dlist = atom->orbital_start;
   while (dlist != NULL)
@@ -210,7 +205,7 @@ if (row == 4)
  * Text: remove text list in atom *
  **********************************/
 
-if (row == 5)
+else if (scope == 5)
   {
   dlist = atom->text_start;
   while (dlist != NULL)
@@ -221,57 +216,129 @@ if (row == 5)
   }
 }
 
-static void static_ok (GtkWidget *widget, void *data)
+static void static_ok_global (int scope, gamgi_window *window)
+{
+gamgi_dlist *dlist, *atoms;
+
+if (gamgi->atoms == NULL)
+  { gamgi_gtk_dialog_message_create ("Error",
+  "Empty list of atoms objects", window); return; }
+
+/************************************************
+ * for all windows: save layers as undo layers, *
+ * set current layer as new current object      *
+ ************************************************/
+
+gamgi_global_selection_undo ();
+gamgi_global_selection_focus ();
+
+/*********************************************************
+ * disable automatic mechanism to remove selection list, *
+ * so we can scan the list and remove it only in the end *
+ *********************************************************/
+
+atoms = gamgi->atoms;
+gamgi->atoms = NULL;
+
+/****************************************************
+ * remove atom data as specified in scope combo box *
+ ****************************************************/
+
+for (dlist = atoms; dlist != NULL; dlist = dlist->next)
+  static_apply (GAMGI_CAST_ATOM dlist->data, scope, window);
+
+/******************************************************
+ * remove the selection list of a class of objects    *
+ * only when objects of that class are really removed *
+ ******************************************************/
+
+gamgi->atoms = atoms;
+if (scope < 2)
+  gamgi_global_selection_remove (&gamgi->atoms, "button_atom");
+
+/*****************************************
+ * For all windows: redraw gl_area image *
+ *****************************************/
+
+gamgi_global_selection_draw ();
+}
+
+static void static_ok_local (int scope, gamgi_window *window)
 {
-gamgi_window *window = GAMGI_CAST_WINDOW data;
 gamgi_atom *atom;
 GtkWidget *dialog = window->dialog0;
-GtkWidget *button;
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+/***************
+ * Pick object *
+ ***************/
+
+atom = GAMGI_CAST_ATOM gamgi_gtk_object_name_number (dialog,
+"entry_atom", GAMGI_ENGINE_ATOM, window);
+if (atom == NULL)
   {
-  /***************
-   * Pick method *
-   ***************/
-
-  atom = GAMGI_CAST_ATOM gamgi_gtk_object_name_number (dialog,
-  "entry_atom", GAMGI_ENGINE_ATOM, window);
-  if (atom == NULL)
-    {
-    gamgi_gtk_dialog_message_create ("Error", "Invalid atom object", window);
-    return;
-    }
-
-  /*************************************************
-   * Before removing the atom, check if the        *
-   * current object is affected. In this case, the *
-   * current layer becomes the new current object. *
-   *************************************************/
-
-  if (gamgi_engine_find_object (window->focus, 
-  GAMGI_CAST_OBJECT atom) == TRUE)
-    gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
-
-  /***************************************
-   * Save current layer as undo buffer   *
-   * layer so it can be recovered later. *
-   ***************************************/
-
-  gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
-
-  /*************************************************
-   * remove atom data as chosen in scope combo box *
-   *************************************************/
-
-  static_apply (atom, window);
+  gamgi_gtk_dialog_message_create ("Error", "Invalid atom object", window);
+  return;
   }
 
+/*************************************************
+ * Before removing the atom, check if the        *
+ * current object is affected. In this case, the *
+ * current layer becomes the new current object. *
+ *************************************************/
+
+if (gamgi_engine_find_object (window->focus,
+GAMGI_CAST_OBJECT atom) == TRUE)
+  gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+
+/***************************************
+ * Save current layer as undo buffer   *
+ * layer so it can be recovered later. *
+ ***************************************/
+
+gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
+
+/*************************************************
+ * remove atom data as chosen in scope combo box *
+ *************************************************/
+
+static_apply (atom, scope, window);
+
 /*********************************************
  * Redraw gl_area image and reset atom entry *
  *********************************************/
 
 gtk_widget_queue_draw (window->area);
+}
+
+static void static_ok (GtkWidget *widget, void *data)
+{
+gamgi_window *window = GAMGI_CAST_WINDOW data;
+GtkWidget *dialog = window->dialog0;
+GtkWidget *button;
+GtkWidget *combo;
+int scope;
+
+/*********************************************************
+ * get dialog data common to both local and global tasks *
+ *********************************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_scope");
+scope = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+/********************************
+ * execute global or local task *
+ ********************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
+  static_ok_global (scope, window);
+else
+  static_ok_local (scope, window);
+
+/***********************************************************
+ * clean dialog data common to both local and global tasks *
+ ***********************************************************/
+
 static_clean (window);
 }
 
@@ -318,7 +385,7 @@ GtkWidget *button;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_global");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
 window_dialog != window_mouse) return;
 
@@ -396,15 +463,15 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 g_object_set_data (G_OBJECT (dialog), "entry_atom", entry);
 gtk_widget_show (entry);
 
-/**********
- * Global *
- **********/
+/********
+ * List *
+ ********/
 
 button = gtk_toggle_button_new_with_label (" List ");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
 g_signal_connect (button, "toggled",
-G_CALLBACK (static_global), window);
-g_object_set_data (G_OBJECT (dialog), "button_global", button);
+G_CALLBACK (static_list), window);
+g_object_set_data (G_OBJECT (dialog), "button_list", button);
 gtk_widget_show (button);
 
 /************
