@@ -85,6 +85,7 @@ gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *label;
 GtkWidget *combo;
+GtkWidget *entry;
 char token[GAMGI_ENGINE_TOKEN];
 int row;
 
@@ -100,7 +101,8 @@ label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_size");
 
 if (row == GAMGI_MESA_WIRED - 1)
   {
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), "");
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  gtk_entry_set_text (GTK_ENTRY (entry), "");
   gtk_widget_set_sensitive (combo, FALSE);
   gtk_widget_set_sensitive (label, FALSE);
   }
@@ -109,7 +111,8 @@ if (row == GAMGI_MESA_SOLID - 1)
   gtk_widget_set_sensitive (combo, TRUE);
   gtk_widget_set_sensitive (label, TRUE);
   sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SIZE, gamgi->bond->size);
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), token);
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 }
 
@@ -190,7 +193,7 @@ entry_atom2 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_atom2")
 label_atom1 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_atom1");
 label_atom2 = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_atom2");
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_direct");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_atoms");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   {
   gtk_widget_hide (vbox);
@@ -268,7 +271,7 @@ gamgi_dlist *dlist;
 gamgi_dlist *atom_list;
 gamgi_dlist *bond_list;
 GtkWidget *button, *combo;
-GtkEntry *entry;
+GtkWidget *entry;
 char token[GAMGI_ENGINE_TOKEN];
 const char *name;
 double min, max;
@@ -294,8 +297,8 @@ if (gamgi_gtk_object_name (dialog, "entry_bond", "", bond->object.name) == FALSE
  * get properties: covalency, order *
  ************************************/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_covalency");
-name = gtk_entry_get_text (entry);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_covalency");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE && 
 gamgi_io_token_float_scan (name, &bond->covalency, 0, FLT_MAX) == FALSE)
   {
@@ -305,7 +308,8 @@ gamgi_io_token_float_scan (name, &bond->covalency, 0, FLT_MAX) == FALSE)
   }
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_order");
-name = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child));
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_float_scan (name, &bond->order, 0, FLT_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Order Data", window);
@@ -330,9 +334,10 @@ if (row == GAMGI_MESA_SOLID - 1) bond->draw = gamgi_mesa_bond_draw_cylinder;
  * scale *
  *********/
 
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-name = gtk_entry_get_text (entry);
-if (gamgi_io_token_double_scan (name, &bond->object.scale, 0.0, DBL_MAX) == FALSE)
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
+if (gamgi_io_token_double_scan (name, &bond->object.scale,
+GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
   gamgi_engine_remove_bond (bond); 
@@ -345,7 +350,8 @@ if (gamgi_io_token_double_scan (name, &bond->object.scale, 0.0, DBL_MAX) == FALS
 
 bond->size = gamgi->bond->size;
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
-name = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child));
+entry = gtk_bin_get_child (GTK_BIN (combo));
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (bond->draw == gamgi_mesa_bond_draw_cylinder &&
 gamgi_io_token_float_scan (name, &bond->size, 0.0, FLT_MAX) == FALSE)
   {
@@ -369,8 +375,8 @@ else
  ******************/
 
 bond->red = gamgi->bond->red;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_red");
-name = gtk_entry_get_text (entry);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (bond->color == TRUE && 
 gamgi_io_token_float_scan (name, &bond->red, 0.0, 1.0) == FALSE)
   {
@@ -380,8 +386,8 @@ gamgi_io_token_float_scan (name, &bond->red, 0.0, 1.0) == FALSE)
   }
 
 bond->green = gamgi->bond->green;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_green");
-name = gtk_entry_get_text (entry);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (bond->color == TRUE && 
 gamgi_io_token_float_scan (name, &bond->green, 0.0, 1.0) == FALSE)
   {
@@ -391,8 +397,8 @@ gamgi_io_token_float_scan (name, &bond->green, 0.0, 1.0) == FALSE)
   }
 
 bond->blue = gamgi->bond->blue;
-entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
-name = gtk_entry_get_text (entry);
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
+name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (bond->color == TRUE && 
 gamgi_io_token_float_scan (name, &bond->blue, 0.0, 1.0) == FALSE)
   {
@@ -406,7 +412,7 @@ gamgi_io_token_float_scan (name, &bond->blue, 0.0, 1.0) == FALSE)
  * used to create bonds *
  ************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_direct");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_atoms");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
   {
   /***************
@@ -483,8 +489,8 @@ else
   element1 = -1;
   element2 = -1;
 
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_element1");
-  name = gtk_entry_get_text (entry);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element1");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_check (name) == TRUE &&
   (gamgi_io_token_alpha_scan (name, token, GAMGI_IO_TEXT, 
   GAMGI_ENGINE_TOKEN) == FALSE || gamgi_chem_atom_number (token, &element1) == FALSE))
@@ -494,8 +500,8 @@ else
     return;
     }
 
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_element2");
-  name = gtk_entry_get_text (entry);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element2");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_check (name) == TRUE &&
   (gamgi_io_token_alpha_scan (name, token, GAMGI_IO_TEXT,
   GAMGI_ENGINE_TOKEN) == FALSE || gamgi_chem_atom_number (token, &element2) == FALSE))
@@ -527,8 +533,8 @@ else
   min = -1.0;
   max = -1.0;
 
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_minimum");
-  name = gtk_entry_get_text (entry);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_minimum");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_check (name) == TRUE && 
   gamgi_io_token_double_scan (name, &min, 0.0, DBL_MAX) == FALSE)
     {
@@ -537,8 +543,8 @@ else
     return;
     }
 
-  entry = (GtkEntry *) g_object_get_data (G_OBJECT (dialog), "entry_maximum");
-  name = gtk_entry_get_text (entry);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_maximum");
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_check (name) == TRUE && 
   gamgi_io_token_double_scan (name, &max, 0.0, DBL_MAX) == FALSE)
     {
@@ -672,8 +678,7 @@ if (bond_class->draw == gamgi_mesa_bond_draw_cylinder)
   gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_MESA_SOLID - 1);
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_color");
-if (bond_class->color == TRUE)
-  gtk_button_clicked (GTK_BUTTON (button));
+gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
@@ -743,7 +748,7 @@ static_ok (NULL, window);
  ***********************************************/
 
 void gamgi_gtk_bond_create_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -754,7 +759,7 @@ const char *name1, *name2;
  * local mouse selection only *
  ******************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_direct");
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_atoms");
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE ||
 window_dialog != window_mouse) return;
 
@@ -782,10 +787,9 @@ void gamgi_gtk_bond_create (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top, *vbox_top_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
@@ -844,32 +848,26 @@ gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/*************
- * Mode page *
- *************/
+/***************
+ * method page *
+ ***************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new (" Mode ");
+label = gtk_label_new ("Method");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /********
- * Mode *
+ * Type *
  ********/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -880,17 +878,17 @@ hbox_left = gtk_hbox_new (FALSE, 5);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
-button = gtk_radio_button_new_with_label (NULL, "Direct");
+button = gtk_radio_button_new_with_label (NULL, "Atoms");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_method), window);
-g_object_set_data (G_OBJECT (dialog), "button_direct", button);
+g_object_set_data (G_OBJECT (dialog), "button_atoms", button);
 gtk_widget_show (button);
 
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Length");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_method), window);
 g_object_set_data (G_OBJECT (dialog), "button_length", button);
 gtk_widget_show (button);
@@ -898,7 +896,7 @@ gtk_widget_show (button);
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Delaunay");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_method), window);
 g_object_set_data (G_OBJECT (dialog), "button_voronoi", button);
 gtk_widget_show (button);
@@ -947,26 +945,20 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Length");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_length", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 /**********
  * Length *
  **********/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
@@ -994,7 +986,7 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_limit), window);
 g_object_set_data (G_OBJECT (dialog), "entry_element1", entry);
 gtk_widget_show (entry);
@@ -1003,7 +995,7 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 5);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_limit), window);
 g_object_set_data (G_OBJECT (dialog), "entry_element2", entry);
 gtk_widget_show (entry);
@@ -1039,28 +1031,22 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_maximum", entry);
 gtk_widget_show (entry);
 
-/*************
- * Type page *
- *************/
+/*****************
+ * Property page *
+ *****************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new (" Type ");
+label = gtk_label_new ("Property");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (2, 2, FALSE);
@@ -1078,8 +1064,9 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_entry_new ();
 gtk_table_attach (GTK_TABLE (table), combo, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 30, 5);
-gtk_entry_set_width_chars (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "combo_order", combo);
 gtk_widget_show (combo);
 
@@ -1123,21 +1110,15 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /********
@@ -1165,7 +1146,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_style), window);
 g_object_set_data (G_OBJECT (dialog), "combo_style", combo);
 gtk_widget_show (combo);
@@ -1216,8 +1197,9 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_entry_new ();
 gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "combo_size", combo);
 gtk_widget_show (combo);
 
@@ -1250,7 +1232,7 @@ gtk_widget_show (table);
 
 button = gtk_toggle_button_new_with_label (" Color ");
 gtk_table_attach (GTK_TABLE (table), button, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_color), window);
 g_object_set_data (G_OBJECT (dialog), "button_color", button);
 gtk_widget_show (button);
@@ -1301,18 +1283,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
