@@ -85,6 +85,7 @@ static void static_style (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog = window->dialog0;
 GtkWidget *combo;
+GtkWidget *entry;
 GtkWidget *label;
 char token[GAMGI_ENGINE_TOKEN];
 int row;
@@ -101,7 +102,8 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
 
 if (row == GAMGI_MESA_WIRED - 1)
   {
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), "");
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  gtk_entry_set_text (GTK_ENTRY (entry), "");
   gtk_widget_set_sensitive (combo, FALSE);
   gtk_widget_set_sensitive (label, FALSE);
   }
@@ -114,11 +116,13 @@ else
 if (row == GAMGI_MESA_SOLID - 1)
   {
   sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SIZE, gamgi->bond->size);
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), token);
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  gtk_entry_set_text (GTK_ENTRY (entry), token);
   }
 else
   {
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), "");
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  gtk_entry_set_text (GTK_ENTRY (entry), "");
   }
 }
 
@@ -143,7 +147,8 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_covalency");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_order");
-gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), "");
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_style");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 2);
@@ -154,7 +159,8 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 2);
 static_color (NULL, window);
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
-gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), "");
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_text (GTK_ENTRY (entry), "");
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 gtk_entry_set_text (GTK_ENTRY (entry), "");
@@ -280,7 +286,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    *************/
 
   combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_order");
-  name = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child));
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_check (name) == TRUE && 
   gamgi_io_token_float_scan (name, &order, 0, FLT_MAX) == FALSE)
     {
@@ -303,8 +310,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
   name = gtk_entry_get_text (GTK_ENTRY (entry));
-  if (gamgi_io_token_check (name) == TRUE &&
-  gamgi_io_token_double_scan (name, &scale, 0.0, DBL_MAX) == FALSE)
+  if (gamgi_io_token_check (name) == TRUE && gamgi_io_token_double_scan (name,
+  &scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
     return;
@@ -316,7 +323,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   if (draw != bond->draw) size = gamgi->bond->size;
   combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
-  name = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo)->child));
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  name = gtk_entry_get_text (GTK_ENTRY (entry));
   if (gamgi_io_token_check (name) == TRUE && (draw == gamgi_mesa_bond_draw_line
   || gamgi_io_token_float_scan (name, &size, 0.0, FLT_MAX) == FALSE))
     {
@@ -417,7 +425,7 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *combo;
 
 /************************************
- * initialize style option_menu and *
+ * initialize style combo box and   *
  * everything that depends of style *
  ************************************/
 
@@ -426,7 +434,7 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 2);
 static_style (NULL, window);
 
 /************************************
- * initialize color option_menu and *
+ * initialize color combo box and   *
  * everything that depends of color *
  ************************************/
 
@@ -469,7 +477,8 @@ if (bond->covalency + GAMGI_MATH_TOLERANCE >= 0)
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_order");
 sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_ORDER, bond->order);
-gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), string);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_text (GTK_ENTRY (entry), string);
 
 /*************
  * Get style *
@@ -490,7 +499,8 @@ if (bond->draw == gamgi_mesa_bond_draw_cylinder)
   {
   combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_size");
   sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SIZE, bond->size);
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo)->child), string);
+  entry = gtk_bin_get_child (GTK_BIN (combo));
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
   }
 
 /*************
@@ -540,7 +550,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), string);
  ***********************************************/
 
 void gamgi_gtk_bond_modify_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -569,10 +579,9 @@ void gamgi_gtk_bond_modify (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left, *hbox_left_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top, *vbox_top_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *button;
 GtkWidget *label;
 GtkWidget *entry;
@@ -636,7 +645,7 @@ gtk_widget_show (entry);
 
 button = gtk_toggle_button_new_with_label ("Global");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "toggled",
+g_signal_connect (button, "toggled",
 G_CALLBACK (static_global), window);
 g_object_set_data (G_OBJECT (dialog), "button_global", button);
 gtk_widget_show (button);
@@ -651,28 +660,22 @@ gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
 
-/*************
- * Type page *
- *************/
+/*****************
+ * property page *
+ *****************/
 
 vbox_page = gtk_vbox_new (FALSE, 5);
-label = gtk_label_new (" Type ");
+label = gtk_label_new ("Property");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_frame), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (2, 2, FALSE);
@@ -690,8 +693,9 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_entry_new ();
 gtk_table_attach (GTK_TABLE (table), combo, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 30, 5);
-gtk_entry_set_width_chars (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "combo_order", combo);
 gtk_widget_show (combo);
 
@@ -735,28 +739,22 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
-
-vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+vbox_top = gtk_vbox_new (FALSE, 15);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 15);
+hbox_left = gtk_hbox_new (FALSE, 20);
 gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
 gtk_widget_show (hbox_left);
 
@@ -774,7 +772,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_style), window);
 g_object_set_data (G_OBJECT (dialog), "combo_style", combo);
 gtk_widget_show (combo);
@@ -793,6 +791,42 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
+/******************
+ * Size combo box *
+ ******************/
+
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+label = gtk_label_new ("Size");
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "label_size", label);
+gtk_widget_show (label);
+
+combo = gtk_combo_box_entry_new ();
+gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+entry = gtk_bin_get_child (GTK_BIN (combo));
+gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
+g_object_set_data (G_OBJECT (dialog), "combo_size", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.3);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.4);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_list_store_append (store, &iter);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.5);
+gtk_list_store_set (store, &iter, 0, token, -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
+
 /*********
  * Scale *
  *********/
@@ -812,47 +846,16 @@ gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "entry_scale", entry);
 gtk_widget_show (entry);
 
-/******************
- * Size combo box *
- ******************/
+/******************************
+ * Color first row: combo box *
+ ******************************/
 
 vbox_top_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top_top);
 
-label = gtk_label_new ("Size");
-gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_size", label);
-gtk_widget_show (label);
-
-combo = gtk_combo_box_entry_new ();
-gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
-gtk_entry_set_width_chars (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
-gtk_entry_set_max_length (GTK_ENTRY (GTK_BIN (combo)->child), GAMGI_GTK_CHAR_5);
-g_object_set_data (G_OBJECT (dialog), "combo_size", combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.3);
-gtk_list_store_set (store, &iter, 0, token, -1);
-gtk_list_store_append (store, &iter);
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.4);
-gtk_list_store_set (store, &iter, 0, token, -1);
-gtk_list_store_append (store, &iter);
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, 0.5);
-gtk_list_store_set (store, &iter, 0, token, -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (combo), 0);
-
-/**************
- * Bond color *
- **************/
-
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 hbox_left = gtk_hbox_new (FALSE, 5);
@@ -866,7 +869,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_color), window);
 g_object_set_data (G_OBJECT (dialog), "combo_color", combo);
 gtk_widget_show (combo);
@@ -885,46 +888,54 @@ renderer = gtk_cell_renderer_text_new ();
 gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
 gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
 
-/***************
- * color R,G,B *
- ***************/
+/***************************
+ * Color second row: R G B *
+ ***************************/
+
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+table = gtk_table_new (1, 6, FALSE);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
+gtk_widget_show (table);
+
+label = gtk_label_new ("R");
+gtk_table_attach (GTK_TABLE (table), label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_red", label);
+gtk_widget_show (label);
+
+label = gtk_label_new ("G");
+gtk_table_attach (GTK_TABLE (table), label, 3, 4, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_green", label);
+gtk_widget_show (label);
+
+label = gtk_label_new ("B");
+gtk_table_attach (GTK_TABLE (table), label, 5, 6, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+g_object_set_data (G_OBJECT (dialog), "label_blue", label);
+gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "entry_red", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("R");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_red", label);
-gtk_widget_show (label);
-
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "entry_green", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("G");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_green", label);
-gtk_widget_show (label);
-
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 4, 5, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 g_object_set_data (G_OBJECT (dialog), "entry_blue", entry);
 gtk_widget_show (entry);
 
-label = gtk_label_new ("B");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_blue", label);
-gtk_widget_show (label);
-
 /*********************
  * Ok/Cancel buttons *
  *********************/
@@ -935,18 +946,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
