@@ -960,9 +960,11 @@ else
   { cell->o1 = o1; cell->o2 = o2; cell->o3 = o3; }
 
 gamgi_phys_cell_create (cell);
-gamgi_gtk_cell_align_angle (cell, euler, window);
-gamgi_gtk_cell_align_origin (cell, origin, window);
+
+gamgi_gtk_cell_align_rotation_get (cell, euler, window);
 gamgi_math_position_cell_rotation_set (cell, euler);
+
+gamgi_gtk_cell_align_translation_get (cell, origin, window);
 gamgi_math_position_cell_translation_set (cell, origin);
 
 /***************************************
