@@ -18,6 +18,7 @@
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
+#include "gamgi_gtk_cell_shift.h"
 #include "gamgi_mesa_select.h"
 #include "gamgi_phys_cell_link.h"
 #include "gamgi_phys_space.h"
@@ -671,7 +672,7 @@ else
   }
 }
 
-static void static_object (gamgi_cell *cell, 
+static void static_ok_object (gamgi_cell *cell, 
 gamgi_object *object, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -686,7 +687,7 @@ else
 static_clean (cell, window);
 }
 
-static void static_crystallographic (gamgi_cell *cell, 
+static void static_ok_crystal (gamgi_cell *cell, 
 gamgi_object *object, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -699,9 +700,10 @@ char token[GAMGI_ENGINE_TOKEN];
 double position[3];
 gamgi_enum vectors, cutoff;
 gamgi_bool nodes_p, nodes_i, nodes_a, nodes_b, nodes_c, nodes_r; 
+double rotation[9];
+double translation[3];
 const int *driver; 
-int site;
-int row;
+int site, row;
 
 /***************************************
  * Currently only atoms are supported, *
@@ -714,17 +716,6 @@ if (object->class != GAMGI_ENGINE_ATOM)
   return;
   }
 
-/*************************
- * get vectors combo box *
- *************************/
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-vectors = FALSE;
-if (row == GAMGI_PHYS_CONVENTIONAL - 1) vectors = GAMGI_PHYS_CONVENTIONAL;
-if (row == GAMGI_PHYS_PRIMITIVE - 1) vectors = GAMGI_PHYS_PRIMITIVE;
-
 /*************************
  * get wyckoff combo box *
  *************************/
@@ -769,13 +760,20 @@ gamgi_io_token_double_scan (name, &position[2], -DBL_MAX, DBL_MAX) == FALSE)
   return;
   }
 
-/*********************************************************************
- * coordinates for referential vectors must be real, coordinates for *
- * conventional and primitive vectors must be in the range ]-1, +1[  *
- *********************************************************************/
+/*************************
+ * get vectors combo box *
+ *************************/
 
-if (vectors != FALSE && (abs (position[0]) >= 1.0 || 
-abs (position[1]) >= 1.0 || abs (position[2]) >= 1.0))
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
+vectors = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+/********************************************************************
+ * coordinates for absolute vectors must be real, coordinates for   *
+ * conventional and primitive vectors must be in the range ]-1, +1[ *
+ ********************************************************************/
+
+if ((vectors == GAMGI_PHYS_CONVENTIONAL || vectors == GAMGI_PHYS_PRIMITIVE) &&
+(abs (position[0]) >= 1.0 || abs (position[1]) >= 1.0 || abs (position[2]) >= 1.0))
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Vector Coordinates", window);
   return;
@@ -847,13 +845,20 @@ GAMGI_IO_RULES, GAMGI_ENGINE_STRING) == FALSE)
 
 gamgi_gtk_history_update (window->layer, window->layer->undo, GAMGI_ENGINE_UNDO);
 
+/*******************************************
+ * get shift translation and rotation data *
+ *******************************************/
+
+gamgi_gtk_cell_shift_rotation_get (cell, rotation, window);
+gamgi_gtk_cell_shift_translation_get (cell, translation, window);
+
 /**********************************
  * link objects to cell and reset *
  **********************************/
 
 gamgi_phys_cell_link (cell, GAMGI_CAST_ATOM object, vectors, wyckoff, 
-driver, site, position, cutoff, nodes_p, nodes_i, nodes_a, nodes_b, 
-nodes_c, nodes_r, rule_a, rule_b, rule_c, window);
+driver, site, position, translation, rotation, cutoff,nodes_p, nodes_i,
+nodes_a, nodes_b, nodes_c, nodes_r, rule_a, rule_b, rule_c, window);
 
 static_clean (cell, window);
 
@@ -864,7 +869,7 @@ static_clean (cell, window);
 gtk_widget_queue_draw (window->area);
 }
 
-static void static_random (gamgi_cell *cell, 
+static void static_ok_random (gamgi_cell *cell, 
 gamgi_object *object, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -998,9 +1003,9 @@ row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
  * get method: object, crystallographic, random *
  ************************************************/
 
-if (row == 0) static_object (cell, object, window);
-if (row == 1) static_crystallographic (cell, object, window);
-if (row == 2) static_random (cell, object, window);
+if (row == 0) static_ok_object (cell, object, window);
+if (row == 1) static_ok_crystal (cell, object, window);
+if (row == 2) static_ok_random (cell, object, window);
 }
 
 static void static_init (gamgi_window *window)
@@ -1054,6 +1059,12 @@ gtk_widget_set_size_request (notebook, size.width, size.height);
 
 combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_method");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+
+/************************
+ * reset position shift *
+ ************************/
+
+gamgi_gtk_cell_shift_start ();
 }
 
 static void static_press (gamgi_object *object, void *data)
@@ -1385,7 +1396,7 @@ vbox_center = gtk_vbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
 gtk_widget_show (vbox_center);
 
-vbox_top = gtk_vbox_new (FALSE, 10);
+vbox_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
@@ -1420,7 +1431,7 @@ gtk_list_store_set (store, &iter, 0, "Conventional", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "Primitive", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Local", -1);
+gtk_list_store_set (store, &iter, 0, "Absolute", -1);
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
 g_object_unref (store);
 
@@ -1460,20 +1471,8 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  * Coordinates *
  ***************/
 
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-vbox_top_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), vbox_top_top, FALSE, FALSE, 0);
-gtk_widget_show (vbox_top_top);
-
-label = gtk_label_new ("Coordinates");
-gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
-gtk_widget_show (label);
-
 table = gtk_table_new (1, 6, FALSE);
-gtk_box_pack_start (GTK_BOX (vbox_top_top), table, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), table, FALSE, FALSE, 0);
 gtk_widget_show (table);
 
 entry = gtk_entry_new ();
@@ -1509,6 +1508,32 @@ label = gtk_label_new ("Z");
 gtk_table_attach (GTK_TABLE (table), label, 5, 6, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_widget_show (label);
 
+hbox_center = gtk_hbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
+gtk_widget_show (hbox_center);
+
+hbox_left = gtk_hbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
+
+button = gtk_toggle_button_new_with_label ("Translation");
+gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
+g_signal_connect (button, "clicked",
+G_CALLBACK (gamgi_gtk_cell_shift_translation), window);
+g_object_set_data (G_OBJECT (dialog), "button_translation", button);
+gtk_widget_show (button);
+
+label = gtk_label_new ("Shift");
+gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+button = gtk_toggle_button_new_with_label ("Rotation");
+gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
+g_signal_connect (button, "clicked",
+G_CALLBACK (gamgi_gtk_cell_shift_rotation), window);
+g_object_set_data (G_OBJECT (dialog), "button_rotation", button);
+gtk_widget_show (button);
+
 /******************
  * Occupancy page *
  ******************/
