@@ -31,6 +31,7 @@
 #include "gamgi_math_matrix.h"
 #include "gamgi_math_quaternion.h"
 #include "gamgi_math_euler.h"
+#include "gamgi_math_cell.h"
 #include "gamgi_math_node.h"
 #include "gamgi_math_position.h"
 #include "gamgi_phys_cell.h"
@@ -326,7 +327,9 @@ row_type != GAMGI_PHYS_SPHERE - 1)
   gtk_entry_set_text (GTK_ENTRY (entry_v1), "");
 
 if (row_type == GAMGI_PHYS_CONVENTIONAL - 1 ||
-row_type == GAMGI_PHYS_PRIMITIVE - 1 || row_type == GAMGI_PHYS_WIGNER - 1)
+row_type == GAMGI_PHYS_PRIMITIVE - 1 ||
+row_type == GAMGI_PHYS_WIGNER - 1 ||
+row_type == GAMGI_PHYS_PROJECTION - 1)
   {
   /******************
    * disable widget *
@@ -401,7 +404,7 @@ else
 
 sensitive = (gamgi_bool *) g_object_get_data (G_OBJECT (dialog), "sensitive_borders");
 combo_borders = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_borders");
-row_borders = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+row_borders = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_borders));
 
 if (row_type == GAMGI_PHYS_PARALLELEPIPED - 1 ||
 row_type == GAMGI_PHYS_SPHERE - 1 || row_type == GAMGI_PHYS_PROJECTION - 1)
@@ -735,7 +738,7 @@ const char *name_system, *name_lattice, *name_group;
 const char *name;
 double euler_old[3], origin_old[3];
 double euler[3], origin[3];
-double zero[3];
+double offset[3];
 double a, b, c, ab, ac, bc;
 double v1, v2, v3, v12, v13, v23;
 double scale;
@@ -1443,13 +1446,14 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
     gamgi_math_vector_add (euler, euler_old, euler);
 
-  /**************
-   * reset cell *
-   **************/
+  /***********************************************************
+   * reset cell: quaternion becomes 0,0,0,1 and origin 0,0,0 *
+   ***********************************************************/
 
-  gamgi_math_vector_zero (zero);
-  gamgi_math_position_cell_rotation_set (cell, zero);
-  gamgi_math_position_cell_translation_set (cell, zero);
+  gamgi_math_vector_zero (offset);
+  gamgi_math_position_cell_rotation_set (cell, offset);
+  gamgi_math_cell_offset (cell, offset);
+  gamgi_math_position_cell_translation_set (cell, offset);
 
   free (cell->points);
   free (cell->loops);
@@ -1508,9 +1512,11 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   cell->object.scale = scale;
 
   gamgi_phys_cell_create (cell);
-  gamgi_gtk_cell_align_angle (cell, euler, window);
+
+  gamgi_gtk_cell_align_rotation_get (cell, euler, window);
   gamgi_math_position_cell_rotation_set (cell, euler);
-  gamgi_gtk_cell_align_origin (cell, origin, window);
+
+  gamgi_gtk_cell_align_translation_get (cell, origin, window);
   gamgi_math_position_cell_translation_set (cell, origin);
   }
 
@@ -2217,7 +2223,7 @@ gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (1, 6, FALSE);
-gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
 gtk_widget_show (table);
 
 label = gtk_label_new ("X");
@@ -2307,7 +2313,7 @@ gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
 table = gtk_table_new (1, 6, FALSE);
-gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
 gtk_widget_show (table);
 
 label = gtk_label_new ("E1");
