@@ -677,10 +677,8 @@ if (gamgi_io_token_int_scan (name, &number, 1, 230) == FALSE)
  * should not be used to change system entry again!  *
  *****************************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry_lattice),
-G_CALLBACK (static_changed_lattice), window);
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry_group),
-G_CALLBACK (static_changed_group), window);
+g_signal_handlers_block_by_func (entry_lattice, static_changed_lattice, window);
+g_signal_handlers_block_by_func (entry_group, static_changed_group, window);
 
 /**************************************************
  * set lattice,group if system provides no choice *
@@ -773,10 +771,8 @@ if (number == 0 || strcmp (system, groups[4*(number - 1) + 2]) != 0)
  * so they accept changes done directly in those entries *
  *********************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry_lattice),
-G_CALLBACK (static_changed_lattice), window);
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry_group),
-G_CALLBACK (static_changed_group), window);
+g_signal_handlers_unblock_by_func (entry_lattice, static_changed_lattice, window);
+g_signal_handlers_unblock_by_func (entry_group, static_changed_group, window);
 
 static_parameters (window);
 }
@@ -827,10 +823,8 @@ if (gamgi_io_token_int_scan (name, &number, 1, 230) == FALSE)
  * should not be used to change lattice entry again! *
  *****************************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry_system),
-G_CALLBACK (static_changed_system), window);
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry_group),
-G_CALLBACK (static_changed_group), window);
+g_signal_handlers_block_by_func (entry_system, static_changed_system, window);
+g_signal_handlers_block_by_func (entry_group, static_changed_group, window);
 
 /**************************************************
  * set system,group if lattice provides no choice *
@@ -913,10 +907,8 @@ if (number == 0 || strcmp (lattice, groups[4*(number - 1) + 3]) != 0)
  * so they accept changes done directly in those entries *
  *********************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry_system),
-G_CALLBACK (static_changed_system), window);
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry_group),
-G_CALLBACK (static_changed_group), window);
+g_signal_handlers_unblock_by_func (entry_system, static_changed_system, window);
+g_signal_handlers_unblock_by_func (entry_group, static_changed_group, window);
 
 static_parameters (window);
 static_nodes (window);
@@ -968,10 +960,8 @@ GAMGI_IO_TEXT, GAMGI_ENGINE_TOKEN);
  * should not be used to change group entry again!   *
  *****************************************************/
 
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry_system),
-G_CALLBACK (static_changed_system), window);
-gtk_signal_handler_block_by_func (GTK_OBJECT (entry_lattice),
-G_CALLBACK (static_changed_lattice), window);
+g_signal_handlers_block_by_func (entry_system, static_changed_system, window);
+g_signal_handlers_block_by_func (entry_lattice, static_changed_lattice, window);
 
 if (number > 0)
   {
@@ -997,10 +987,8 @@ else
  * so they accept changes done directly in those entries *
  *********************************************************/
 
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry_system),
-G_CALLBACK (static_changed_system), window);
-gtk_signal_handler_unblock_by_func (GTK_OBJECT (entry_lattice),
-G_CALLBACK (static_changed_lattice), window);
+g_signal_handlers_unblock_by_func (entry_system, static_changed_system, window);
+g_signal_handlers_unblock_by_func (entry_lattice, static_changed_lattice, window);
 
 static_parameters (window);
 }
@@ -1111,7 +1099,7 @@ int n;
 
 dialog = gamgi_gtk_dialog_task1_create ("Crystalographic Systems", window);
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (static_delete), window);
 
 vbox_dialog = gtk_vbox_new (FALSE, 5);
@@ -1122,7 +1110,7 @@ treeview = gtk_tree_view_new ();
 gtk_container_add (GTK_CONTAINER (vbox_dialog), treeview);
 selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
-g_signal_connect (GTK_OBJECT (treeview), "cursor-changed",
+g_signal_connect (treeview, "cursor-changed",
 G_CALLBACK (static_select_system), window);
 gtk_widget_show (treeview);
 
@@ -1175,9 +1163,8 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_remove), window);
 gtk_widget_show (button);
 
@@ -1204,7 +1191,7 @@ int n;
 
 dialog = gamgi_gtk_dialog_task1_create ("Crystalographic Lattices", window);
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (static_delete), window);
 
 vbox_dialog = gtk_vbox_new (FALSE, 5);
@@ -1215,10 +1202,11 @@ treeview = gtk_tree_view_new ();
 gtk_container_add (GTK_CONTAINER (vbox_dialog), treeview);
 selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
-g_signal_connect (GTK_OBJECT (treeview), "cursor-changed",
+g_signal_connect (treeview, "cursor-changed",
 G_CALLBACK (static_select_lattice), window);
 gtk_widget_show (treeview);
 
+
 renderer = gtk_cell_renderer_text_new ();
 column = gtk_tree_view_column_new_with_attributes ("Lattices", renderer, "text", 0, NULL);
 gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
@@ -1268,9 +1256,8 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_remove), window);
 gtk_widget_show (button);
 
@@ -1299,7 +1286,7 @@ int n;
 
 dialog = gamgi_gtk_dialog_task1_create ("Crystalographic Space Groups", window);
 gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
-g_signal_connect (GTK_OBJECT (dialog), "delete_event",
+g_signal_connect (dialog, "delete_event",
 G_CALLBACK (static_delete), window);
 
 vbox_dialog = gtk_vbox_new (FALSE, 5);
@@ -1316,7 +1303,7 @@ treeview = gtk_tree_view_new ();
 gtk_container_add (GTK_CONTAINER (scrolled_window), treeview);
 selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
 gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
-g_signal_connect (GTK_OBJECT (treeview), "cursor-changed",
+g_signal_connect (treeview, "cursor-changed",
 G_CALLBACK (static_select_group), window);
 gtk_widget_show (treeview);
 
@@ -1374,9 +1361,8 @@ gtk_widget_show (hbox_center);
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_remove), window);
 gtk_widget_show (button);
 
@@ -1851,29 +1837,28 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_group");
 gtk_entry_set_text (GTK_ENTRY (entry), group);
 }
 
-GtkWidget *gamgi_gtk_cell_symmetry (GtkWidget *vbox_page, gamgi_window *window)
+void gamgi_gtk_cell_symmetry (GtkWidget *notebook, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *label;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left;
-GtkWidget *vbox_frame, *vbox_top;
+GtkWidget *vbox_page, *vbox_center, *vbox_top;
 GtkWidget *button;
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
+vbox_page = gtk_vbox_new (FALSE, 5);
+label = gtk_label_new ("Symmetry");
+gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
+gtk_widget_show (vbox_page);
 
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 hbox_center = gtk_hbox_new (TRUE, 0);
@@ -1890,17 +1875,17 @@ gtk_widget_show (table);
 
 label = gtk_label_new ("System");
 gtk_table_attach (GTK_TABLE (table), 
-label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 3);
+label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
 gtk_widget_show (label);
 
 label = gtk_label_new ("Lattice");
 gtk_table_attach (GTK_TABLE (table), 
-label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 3);
+label, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
 gtk_widget_show (label);
 
 label = gtk_label_new ("Group");
 gtk_table_attach (GTK_TABLE (table), 
-label, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 3);
+label, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
 gtk_widget_show (label);
 
 /**********
@@ -1914,7 +1899,7 @@ gtk_widget_show (hbox_left);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_clicked_system), window);
 g_object_set_data (G_OBJECT (dialog), "button_system", button);
 gtk_widget_show (button);
@@ -1923,7 +1908,7 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_changed_system), window);
 g_object_set_data (G_OBJECT (dialog), "entry_system", entry);
 gtk_widget_show (entry);
@@ -1939,7 +1924,7 @@ gtk_widget_show (hbox_left);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_clicked_lattice), window);
 g_object_set_data (G_OBJECT (dialog), "button_lattice", button);
 gtk_widget_show (button);
@@ -1948,7 +1933,7 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_changed_lattice), window);
 g_object_set_data (G_OBJECT (dialog), "entry_lattice", entry);
 gtk_widget_show (entry);
@@ -1964,7 +1949,7 @@ gtk_widget_show (hbox_left);
 
 button = gtk_toggle_button_new_with_label ("List");
 gtk_box_pack_end (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_clicked_group), window);
 g_object_set_data (G_OBJECT (dialog), "button_group", button);
 gtk_widget_show (button);
@@ -1973,7 +1958,7 @@ entry = gtk_entry_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_3);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_changed_group), window);
 g_object_set_data (G_OBJECT (dialog), "entry_group", entry);
 gtk_widget_show (entry);
@@ -1994,17 +1979,17 @@ label = gtk_label_new ("Length");
 gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_widget_show (label);
 
-label = gtk_label_new ("a");
+label = gtk_label_new ("A");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_a", label);
 gtk_widget_show (label);
 
-label = gtk_label_new ("b");
+label = gtk_label_new ("B");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_b", label);
 gtk_widget_show (label);
 
-label = gtk_label_new ("c");
+label = gtk_label_new ("C");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_c", label);
 gtk_widget_show (label);
@@ -2013,17 +1998,17 @@ label = gtk_label_new ("Angle");
 gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 0);
 gtk_widget_show (label);
 
-label = gtk_label_new ("bc");
+label = gtk_label_new ("BC");
 gtk_table_attach (GTK_TABLE (table), label, 2, 3, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_bc", label);
 gtk_widget_show (label);
 
-label = gtk_label_new ("ac");
+label = gtk_label_new ("AC");
 gtk_table_attach (GTK_TABLE (table), label, 4, 5, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_ac", label);
 gtk_widget_show (label);
 
-label = gtk_label_new ("ab");
+label = gtk_label_new ("AB");
 gtk_table_attach (GTK_TABLE (table), label, 6, 7, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 g_object_set_data (G_OBJECT (dialog), "label_ab", label);
 gtk_widget_show (label);
@@ -2077,6 +2062,4 @@ gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_ab", entry);
 gtk_widget_show (entry);
-
-return frame;
 }
