@@ -745,8 +745,8 @@ if (gamgi_io_token_float_scan (name, &direction->blue, 0.0, 1.0) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (direction->autonomy != GAMGI_GTK_NONE &&
-gamgi_io_token_double_scan (name, &direction->object.scale, 0.0, DBL_MAX) == FALSE)
+if (direction->autonomy != GAMGI_GTK_NONE && gamgi_io_token_double_scan (name,
+&direction->object.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
   gamgi_engine_remove_direction (direction);
@@ -879,7 +879,8 @@ if (direction->reference == GAMGI_ENGINE_ATOM)
 
   parent = gamgi_phys_direction_parent (atom1, atom2, window);
   dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-  dlist = gamgi_phys_direction_filter (dlist);
+  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
+  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
   dlist = gamgi_phys_direction_reorder (dlist, atom1, atom2);
   direction->type = GAMGI_PHYS_LINE;
 
@@ -938,15 +939,15 @@ static_cell (NULL, window);
  *****************************/
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, GAMGI_MESA_DIRECTION_R);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, gamgi->direction->red);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_green");
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, GAMGI_MESA_DIRECTION_G);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, gamgi->direction->green);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
-sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, GAMGI_MESA_DIRECTION_B);
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, gamgi->direction->blue);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
 /******************************************
@@ -983,7 +984,7 @@ gtk_entry_set_text (GTK_ENTRY (entry), string);
 }
 
 void gamgi_gtk_direction_create_press (gamgi_window *window_mouse,
-int x, int y, gamgi_window *window_dialog)
+GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
@@ -1089,10 +1090,9 @@ void gamgi_gtk_direction_create (GtkWidget *widget, void *data)
 gamgi_window *window = GAMGI_CAST_WINDOW data;
 GtkWidget *dialog;
 GtkWidget *notebook;
-GtkWidget *frame;
 GtkWidget *table;
 GtkWidget *hbox_center, *hbox_left;
-GtkWidget *vbox_dialog, *vbox_page, *vbox_frame, *vbox_top, *vbox_top_top;
+GtkWidget *vbox_dialog, *vbox_page, *vbox_center, *vbox_top, *vbox_top_top;
 GtkWidget *entry;
 GtkWidget *label;
 GtkWidget *button;
@@ -1148,7 +1148,7 @@ gtk_widget_show (entry);
 notebook = gtk_notebook_new ();
 gtk_box_pack_start (GTK_BOX (vbox_dialog), notebook, FALSE, FALSE, 0);
 gtk_notebook_set_tab_pos (GTK_NOTEBOOK (notebook), GTK_POS_TOP);
-g_signal_connect (GTK_OBJECT (notebook), "switch_page",
+g_signal_connect (notebook, "switch_page",
 G_CALLBACK (static_switch), window);
 g_object_set_data (G_OBJECT (dialog), "notebook", notebook);
 gtk_widget_show (notebook);
@@ -1160,26 +1160,11 @@ gtk_widget_show (notebook);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" Type ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-/********************************************************
- * vbox_frame is not centered, to avoid small shifts    *
- * in the reference position when frame contents change *
- ********************************************************/
-
-vbox_frame = gtk_vbox_new (FALSE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
-
 vbox_top = gtk_vbox_new (FALSE, 10);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /********
@@ -1200,7 +1185,7 @@ gtk_widget_show (label);
 
 button = gtk_radio_button_new_with_label (NULL, "Cell");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_reference), window);
 g_object_set_data (G_OBJECT (dialog), "button_cell", button);
 gtk_widget_show (button);
@@ -1208,7 +1193,7 @@ gtk_widget_show (button);
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Atoms");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_reference), window);
 gtk_widget_show (button);
 
@@ -1237,7 +1222,7 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_20);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_cell), window);
 g_object_set_data (G_OBJECT (dialog), "entry_cell", entry);
 gtk_widget_show (entry);
@@ -1278,7 +1263,7 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_instance), window);
 g_object_set_data (G_OBJECT (dialog), "entry_u", entry);
 gtk_widget_show (entry);
@@ -1287,7 +1272,7 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 3, 4, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_instance), window);
 g_object_set_data (G_OBJECT (dialog), "entry_v", entry);
 gtk_widget_show (entry);
@@ -1296,7 +1281,7 @@ entry = gtk_entry_new ();
 gtk_table_attach (GTK_TABLE (table), entry, 5, 6, 0, 1, GTK_EXPAND, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_5);
-g_signal_connect (GTK_OBJECT (entry), "changed",
+g_signal_connect (entry, "changed",
 G_CALLBACK (static_instance), window);
 g_object_set_data (G_OBJECT (dialog), "entry_w", entry);
 gtk_widget_show (entry);
@@ -1324,7 +1309,7 @@ gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
 gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_vectors), window);
 g_object_set_data (G_OBJECT (dialog), "combo_vectors", combo);
 gtk_widget_show (combo);
@@ -1387,22 +1372,16 @@ gtk_widget_show (entry);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new ("Projection");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_projection", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 20);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /**************
@@ -1461,47 +1440,37 @@ gtk_widget_show (button);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" Line ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 g_object_set_data (G_OBJECT (dialog), "vbox_line", vbox_page);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 15);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /********
  * Link *
  ********/
 
-vbox_top_top = gtk_vbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (vbox_top), vbox_top_top, FALSE, FALSE, 0);
-gtk_widget_show (vbox_top_top);
-
 hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
+table = gtk_table_new (2, 2, FALSE);
+gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
+gtk_widget_show (table);
 
 label = gtk_label_new ("Autonomy");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), combo, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (combo), "changed",
+gtk_table_attach (GTK_TABLE (table), combo, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
+g_signal_connect (combo, "changed",
 G_CALLBACK (static_autonomy), window);
 g_object_set_data (G_OBJECT (dialog), "combo_autonomy", combo);
 gtk_widget_show (combo);
@@ -1524,21 +1493,13 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  * Thickness *
  *************/
 
-hbox_center = gtk_hbox_new (TRUE, 0);
-gtk_box_pack_start (GTK_BOX (vbox_top_top), hbox_center, FALSE, FALSE, 0);
-gtk_widget_show (hbox_center);
-
-hbox_left = gtk_hbox_new (FALSE, 5);
-gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
-gtk_widget_show (hbox_left);
-
 label = gtk_label_new ("Thickness");
-gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 0);
 g_object_set_data (G_OBJECT (dialog), "label_thickness", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_box_pack_start (GTK_BOX (hbox_left), entry, FALSE, FALSE, 0);
+gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_thickness", entry);
@@ -1562,7 +1523,7 @@ gtk_widget_show (hbox_left);
 
 button = gtk_radio_button_new_with_label (NULL, "Node"); 
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_direction_range), window);
 g_object_set_data (G_OBJECT (dialog), "button_node", button);
 gtk_widget_show (button);
@@ -1570,7 +1531,7 @@ gtk_widget_show (button);
 button = gtk_radio_button_new_with_label (
 gtk_radio_button_get_group (GTK_RADIO_BUTTON (button)), "Range");
 gtk_box_pack_start (GTK_BOX (hbox_left), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_direction_range), window);
 g_object_set_data (G_OBJECT (dialog), "button_range", button);
 gtk_widget_show (button);
@@ -1667,21 +1628,15 @@ gtk_widget_show (label);
 vbox_page = gtk_vbox_new (FALSE, 5);
 label = gtk_label_new (" View ");
 gtk_notebook_append_page (GTK_NOTEBOOK (notebook), vbox_page, label);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 5);
+gtk_container_set_border_width (GTK_CONTAINER (vbox_page), 10);
 gtk_widget_show (vbox_page);
 
-frame = gtk_frame_new (NULL);
-gtk_box_pack_start (GTK_BOX (vbox_page), frame, TRUE, TRUE, 0);
-gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_ETCHED_IN);
-gtk_widget_show (frame);
-
-vbox_frame = gtk_vbox_new (TRUE, 0);
-gtk_container_add (GTK_CONTAINER (frame), vbox_frame);
-gtk_container_set_border_width (GTK_CONTAINER (vbox_frame), 5);
-gtk_widget_show (vbox_frame);
+vbox_center = gtk_vbox_new (TRUE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_page), vbox_center, TRUE, TRUE, 0);
+gtk_widget_show (vbox_center);
 
 vbox_top = gtk_vbox_new (FALSE, 20);
-gtk_box_pack_start (GTK_BOX (vbox_frame), vbox_top, FALSE, FALSE, 0);
+gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
 /*********
@@ -1767,18 +1722,16 @@ gtk_widget_show (hbox_center);
 
 button = gamgi_gtk_dialog_button_create ("Ok", NULL);
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (static_ok), window);
 gtk_widget_show (button);
 
 button = gamgi_gtk_dialog_button_create ("Cancel", "red");
 gtk_widget_set_size_request (button, GAMGI_GTK_BUTTON_WIDTH, -1);
-GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 gtk_box_pack_start (GTK_BOX (hbox_center), button, FALSE, FALSE, 0);
 gtk_widget_grab_focus (button);
-g_signal_connect (GTK_OBJECT (button), "clicked",
+g_signal_connect (button, "clicked",
 G_CALLBACK (gamgi_gtk_dialog_task0_remove), window);
 gtk_widget_show (button);
 
