@@ -120,8 +120,8 @@ switch (window->action)
 
   case GAMGI_GTK_BOND_CREATE:
   gamgi_gtk_help_dialog_import ("Help Bond Create",  
-  "interfaces/bond/create", window, 4, n, "mode", "length", 
-  "type", "view");
+  "interfaces/bond/create", window, 4, n, "method", "length", 
+  "property", "view");
   break;
 
   case GAMGI_GTK_BOND_COPY:
@@ -141,7 +141,7 @@ switch (window->action)
 
   case GAMGI_GTK_BOND_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Bond Modify",  
-  "interfaces/bond/modify", window, 2, n, "type", "view");
+  "interfaces/bond/modify", window, 2, n, "property", "view");
   break;
 
   case GAMGI_GTK_BOND_REMOVE:
@@ -156,7 +156,7 @@ switch (window->action)
 
   case GAMGI_GTK_ATOM_CREATE:
   gamgi_gtk_help_dialog_import ("Help Atom Create",  
-  "interfaces/atom/create", window, 5, n, "element",
+  "interfaces/atom/create", window, 5, n, "type",
   "property", "analysis", "position", "view");
   break;
 
@@ -167,7 +167,7 @@ switch (window->action)
 
   case GAMGI_GTK_ATOM_SELECT:
   gamgi_gtk_help_dialog_import ("Help Atom Select",  
-  "interfaces/atom/select", window, 0, n);
+  "interfaces/atom/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_ATOM_LINK:
@@ -177,8 +177,9 @@ switch (window->action)
 
   case GAMGI_GTK_ATOM_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Atom Modify",  
-  "interfaces/atom/modify", window, 5, n, "element",
-  "property", "analysis", "position", "view");
+  "interfaces/atom/modify", window, 7, n, "type",
+  "property", "analysis", "position", "view", "length",
+  "angle");
   break;
 
   case GAMGI_GTK_ATOM_MEASURE:
@@ -193,7 +194,8 @@ switch (window->action)
 
   case GAMGI_GTK_ATOM_CONFIG:
   gamgi_gtk_help_dialog_import ("Help Atom Config",
-  "interfaces/atom/config", window, 0, n);
+  "interfaces/atom/config", window, 3, n, "element",
+  "analysis", "view");
   break;
 
   case GAMGI_GTK_DIRECTION_CREATE:
@@ -272,7 +274,13 @@ switch (window->action)
 
   case GAMGI_GTK_GROUP_CREATE:
   gamgi_gtk_help_dialog_import ("Help Group Create",  
-  "interfaces/group/create", window, 0, n);
+  "interfaces/group/create", window, 4, n, "type",
+  "scope", "tolerance", "view");
+  break;
+
+  case GAMGI_GTK_GROUP_CREATE_POLYTOPE:
+  gamgi_gtk_help_dialog_import ("Help Group Create Polytope",
+  "interfaces/group/create_polytope", window, 0, n);
   break;
 
   case GAMGI_GTK_GROUP_COPY:
@@ -292,8 +300,13 @@ switch (window->action)
 
   case GAMGI_GTK_GROUP_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Group Modify",  
-  "interfaces/group/modify", window, 3, n, "length", 
-  "angle", "torsion");
+  "interfaces/group/modify", window, 4, n, "type", 
+  "scope", "tolerance", "view");
+  break;
+
+  case GAMGI_GTK_GROUP_MODIFY_POLYTOPE:
+  gamgi_gtk_help_dialog_import ("Help Group Modify Polytope",
+  "interfaces/group/modify_polytope", window, 0, n);
   break;
 
   case GAMGI_GTK_GROUP_MEASURE:
@@ -437,7 +450,7 @@ switch (window->action)
   case GAMGI_GTK_CELL_CREATE:
   gamgi_gtk_help_dialog_import ("Help Cell Create",  
   "interfaces/cell/create", window, 5, n, "symmetry", 
-  "type", "position", "origin", "view");
+  "volume", "position", "origin", "view");
   break;
 
   case GAMGI_GTK_CELL_COPY:
@@ -464,7 +477,7 @@ switch (window->action)
   case GAMGI_GTK_CELL_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Cell Modify",  
   "interfaces/cell/modify", window, 5, n, "symmetry", 
-  "type", "position", "origin", "view");
+  "volume", "position", "origin", "view");
   break;
 
   case GAMGI_GTK_CELL_MEASURE:
@@ -609,7 +622,7 @@ switch (window->action)
 
   case GAMGI_GTK_LIGHT_CREATE:
   gamgi_gtk_help_dialog_import ("Help Light Create",  
-  "interfaces/light/create", window, 3, n, "type", "color", "attenuation");
+  "interfaces/light/create", window, 3, n, "geometry", "color", "attenuation");
   break;
 
   case GAMGI_GTK_LIGHT_COPY:
@@ -629,7 +642,7 @@ switch (window->action)
 
   case GAMGI_GTK_LIGHT_MODIFY:
   gamgi_gtk_help_dialog_import ("Help Light Modify",  
-  "interfaces/light/modify", window, 3, n, "type", "color", "attenuation");
+  "interfaces/light/modify", window, 3, n, "geometry", "color", "attenuation");
   break;
 
   case GAMGI_GTK_LIGHT_REMOVE:
@@ -717,12 +730,12 @@ switch (window->action)
 
   case GAMGI_GTK_FILE_IMPORT:
   gamgi_gtk_help_dialog_import ("Help File Import", 
-  "interfaces/file/import", window, 0, n);
+  "interfaces/file/import", window, 2, n, "location", "filters");
   break;
 
   case GAMGI_GTK_FILE_EXPORT:
   gamgi_gtk_help_dialog_import ("Help File Export", 
-  "interfaces/file/export", window, 0, n);
+  "interfaces/file/export", window, 2, n, "location", "filters");
   break;
 
   case GAMGI_GTK_GAMGI_ABOUT:
