@@ -417,56 +417,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   red = text->red;
   green = text->green;
   blue = text->blue;
-
   scale = text->object.scale;
 
-  /*********************
-   * get text contents *
-   *********************/
-
-  text_view = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "text_contents");
-  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
-  gtk_text_buffer_get_start_iter (buffer, &start);
-  gtk_text_buffer_get_end_iter (buffer, &end);
-  contents = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
-  if (gamgi_io_token_check (contents) == TRUE)
-    {
-    /********************
-     * new text message *
-     ********************/
-
-    if (gamgi_io_token_alpha_check (contents,
-    GAMGI_IO_FONT_ASCII, GAMGI_ENGINE_LINE) == FALSE)
-      {
-      gamgi_gtk_dialog_message_create ("Error", "Invalid Text Contents", window);
-      return;
-      }
-
-    if (gamgi_mesa_text_center (font,
-    contents, strlen (contents), center) == FALSE)
-      {
-      gamgi_mesa_text_data_solid (font, token);
-      sprintf (line, "Unable to handle font file \"%s\"", token);
-      gamgi_gtk_dialog_message_create ("Error", line, window);
-      return;
-      }
-    }
-  else
-    {
-    /********************
-     * old text message *
-     ********************/
-
-    if (gamgi_mesa_text_center (font,
-    text->string, text->length, center) == FALSE)
-      {
-      gamgi_mesa_text_data_solid (font, token);
-      sprintf (line, "Unable to handle font file \"%s\"", token);
-      gamgi_gtk_dialog_message_create ("Error", line, window);
-      return;
-      }
-    }
-
   /*********************************************
    * grab data from style and font combo boxes *
    *********************************************/
@@ -693,6 +645,53 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
     return;
     }
 
+  /*********************
+   * get text contents *
+   *********************/
+
+  text_view = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "text_contents");
+  buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (text_view));
+  gtk_text_buffer_get_start_iter (buffer, &start);
+  gtk_text_buffer_get_end_iter (buffer, &end);
+
+  contents = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
+  if (gamgi_io_token_alpha_check (contents,
+  GAMGI_IO_FONT_ASCII, GAMGI_ENGINE_LINE) == FALSE)
+    {
+    gamgi_gtk_dialog_message_create ("Error", "Invalid Text Contents", window);
+    free (contents);
+    return;
+    }
+
+  if (gamgi_io_token_check (contents) == TRUE)
+    {
+    /********************
+     * new text message *
+     ********************/
+
+    if (gamgi_mesa_text_center (font,
+    contents, strlen (contents), center, line) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", line, window);
+      free (contents);
+      return;
+      }
+    }
+  else
+    {
+    /********************
+     * old text message *
+     ********************/
+
+    if (gamgi_mesa_text_center (font,
+    text->string, text->length, center, line) == FALSE)
+      {
+      gamgi_gtk_dialog_message_create ("Error", line, window);
+      free (contents);
+      return;
+      }
+    }
+
   /********************************************************
    * Data is ok: save current data and update to new data *
    ********************************************************/
@@ -753,7 +752,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
     gamgi_mesa_text_remove (text);
     gamgi_mesa_text_create (text, contents);
     text->font = font;
-    gamgi_mesa_text_font_increase (text);
+    gamgi_mesa_text_font_increase (text, NULL);
     }
   else if (font != text->font)
     {
@@ -763,9 +762,15 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
     gamgi_mesa_text_font_decrease (text);
     text->font = font;
-    gamgi_mesa_text_font_increase (text);
+    gamgi_mesa_text_font_increase (text, NULL);
     }
 
+  /***************
+   * free memory *
+   ***************/
+
+  free (contents);
+
   /*********************************************
    * Update the text name, which might be new. *
    *********************************************/
