@@ -332,7 +332,7 @@ int sign;
  * continous variation *
  ***********************/
 
-position = GTK_RULER (window->ruler)->position;
+gtk_ruler_get_range (GTK_RULER (window->ruler), NULL, NULL, &position, NULL);
 position = position / GAMGI_GTK_RULER_MAX * max;
 if (step < GAMGI_MATH_TOLERANCE) return position;
 
@@ -355,8 +355,11 @@ return position;
 
 static void static_ruler_start (gamgi_window *window)
 {
+double lower, upper, max;
+
 window->mode = FALSE;
-GTK_RULER (window->ruler)->position = 0;
+gtk_ruler_get_range (GTK_RULER (window->ruler), &lower, &upper, NULL, &max);
+gtk_ruler_set_range (GTK_RULER (window->ruler), lower, upper, 0, max);
 gtk_widget_set_sensitive (window->ruler, FALSE);
 }
 
@@ -506,7 +509,7 @@ gamgi_gtk_statusbar_color (label, NULL, window);
 label = gtk_bin_get_child (GTK_BIN (move));
 gamgi_gtk_statusbar_color (label, NULL, window);
 label = gtk_bin_get_child (GTK_BIN (scale));
-gamgi_gtk_statusbar_color (scale, NULL, window);
+gamgi_gtk_statusbar_color (label, NULL, window);
 
 /*******************************************
  * mode must be only rotate, move or scale *
@@ -836,7 +839,7 @@ g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_graph_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_graph_copy, window);
-static_item_insert (menu, "Select", NULL, gamgi_gtk_graph_select, window);
+static_item_insert (menu, "Select", "grey", gamgi_gtk_graph_select, window);
 static_item_insert (menu, "Link", "grey", gamgi_gtk_graph_link, window);
 static_item_insert (menu, "Modify", "grey", gamgi_gtk_graph_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_graph_remove, window);
@@ -862,7 +865,7 @@ g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_shape_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_shape_copy, window);
-static_item_insert (menu, "Select", NULL, gamgi_gtk_shape_select, window);
+static_item_insert (menu, "Select", "grey", gamgi_gtk_shape_select, window);
 static_item_insert (menu, "Link", "grey", gamgi_gtk_shape_link, window);
 static_item_insert (menu, "Modify", "grey", gamgi_gtk_shape_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_shape_remove, window);
@@ -888,7 +891,7 @@ g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_arrow_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_arrow_copy, window);
-static_item_insert (menu, "Select", NULL, gamgi_gtk_arrow_select, window);
+static_item_insert (menu, "Select", "grey", gamgi_gtk_arrow_select, window);
 static_item_insert (menu, "Link", "grey", gamgi_gtk_arrow_link, window);
 static_item_insert (menu, "Modify", "grey", gamgi_gtk_arrow_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_arrow_remove, window);
@@ -1131,7 +1134,7 @@ g_object_set_data (G_OBJECT (button), "menu", menu);
 
 static_item_insert (menu, "Create", "grey", gamgi_gtk_orbital_create, window);
 static_item_insert (menu, "Copy", "grey", gamgi_gtk_orbital_copy, window);
-static_item_insert (menu, "Select", NULL, gamgi_gtk_orbital_select, window);
+static_item_insert (menu, "Select", "grey", gamgi_gtk_orbital_select, window);
 static_item_insert (menu, "Link", "grey", gamgi_gtk_orbital_link, window);
 static_item_insert (menu, "Modify", "grey", gamgi_gtk_orbital_modify, window);
 static_item_insert (menu, "Remove", "grey", gamgi_gtk_orbital_remove, window);
@@ -1201,6 +1204,7 @@ static_item_insert (menu, "Config", NULL, gamgi_gtk_help_config, window);
  ****************/
 
 window->area = gamgi_mesa_area_create (window);
+if (window->area == NULL) return;
 gtk_box_pack_start (GTK_BOX (vbox_main), window->area, TRUE, TRUE, 0);
 
 /******************
