@@ -101,9 +101,9 @@ GAMGI_IO_DEJAVU_MONO_ITALIC, GAMGI_IO_DEJAVU_MONO_BOLD_ITALIC };
  * the Gamgi->About GUI dialog *
  *******************************/
 
-#define GAMGI_IO_DATE "20th January 2010"
-#define GAMGI_IO_VERSION "0.14.5"
-#define GAMGI_IO_AUTHORS "Carlos Pereira"
+#define GAMGI_IO_DATE "4th April 2010"
+#define GAMGI_IO_VERSION "0.14.7"
+#define GAMGI_IO_AUTHORS "Carlos Pereira et al."
 #define GAMGI_IO_LICENSE "GPL"
 #define GAMGI_IO_WEBSITE "http://www.gamgi.org/"
 
