@@ -264,7 +264,7 @@ void gamgi_io_file_fprintf (FILE *fp, char *string, gamgi_bool *error)
  * call and check its state only after the last fprintf. If    *
  * error is now TRUE, then at least one fprintf call failed,   *
  * in which case we show an error message saying that we were  *
- * unable to sucessfully write the file and ask the user if    *
+ * unable to successfully write the file and ask the user if   *
  * we should remove it (it is certainly corrupted, but reading *
  * it might give the user a clue anyway about what went wrong) *
  *                                                             *
@@ -983,7 +983,7 @@ shortname = gamgi_io_file_shortname (filename);
 
 fp = fopen (filename, "a+");
 if (fp == NULL)
-  { gamgi_io_error_open (shortname, window); 
+  { gamgi_io_error_write (shortname, window); 
     return; }
 
 /*******************
