@@ -21,6 +21,7 @@
 #include "gamgi_mesa_atom.h"
 #include "gamgi_mesa_render.h"
 #include "gamgi_mesa_axes.h"
+#include "gamgi_mesa_select.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_math_quaternion.h"
 
@@ -441,24 +442,45 @@ void gamgi_mesa_draw_group (gamgi_group *group)
 gamgi_dlist *dlist;
 double rotate[16];
 float background[4];
+double origin[3];
 
 glPushMatrix ();
 
-glTranslatef (group->center[0], group->center[1], group->center[2]);
-glScalef (group->object.scale, group->object.scale, group->object.scale);
-glTranslatef (-group->center[0], -group->center[1], -group->center[2]);
-
-glPushMatrix ();
-
-glTranslatef (group->origin[0], group->origin[1], group->origin[2]);
-
-gamgi_math_quaternion_to_matrix4 (group->quaternion, rotate);
-glMultMatrixd (rotate);
-
-if (group->loops != NULL)
+if (group->loops == NULL)
   {
-  glLineWidth (GAMGI_MESA_CLUSTER_WIDTH);
-  glPointSize (GAMGI_MESA_CLUSTER_WIDTH);
+  /*****************************************************
+   * this contains other objects only, such as atoms:  *
+   * scale to layer center, otherwise changing an atom *
+   * would change the group center, in turn changing *
+   * the aparent position of all the other atoms       *
+   *****************************************************/
+
+  gamgi_math_vector_absolute (origin, 0.0, 0.0, 0.0);
+
+  glTranslatef (origin[0], origin[1], origin[2]);
+  glScalef (group->object.scale, group->object.scale, group->object.scale);
+  glTranslatef (-origin[0], -origin[1], -origin[2]);
+  }
+else
+  {
+  /**********************************************
+   * this group is a polytope: change according *
+   * to group center, origin and quaternion     *
+   **********************************************/
+
+  glTranslatef (group->center[0], group->center[1], group->center[2]);
+  glScalef (group->object.scale, group->object.scale, group->object.scale);
+  glTranslatef (-group->center[0], -group->center[1], -group->center[2]);
+
+  glPushMatrix ();
+
+  glTranslatef (group->origin[0], group->origin[1], group->origin[2]);
+
+  gamgi_math_quaternion_to_matrix4 (group->quaternion, rotate);
+  glMultMatrixd (rotate);
+
+  glLineWidth (GAMGI_MESA_POLYHEDRON_WIDTH);
+  glPointSize (GAMGI_MESA_POLYHEDRON_WIDTH);
 
   glColor3f (group->red, group->green, group->blue);
 
@@ -468,11 +490,11 @@ if (group->loops != NULL)
     glPolygonOffset (1, 1);
 
     glPolygonMode (GL_FRONT, GL_FILL);
-    glDisable(GL_CULL_FACE);
+    glDisable (GL_CULL_FACE);
 
     gamgi_mesa_render_polygons (group->loops, group->points);
 
-    glEnable(GL_CULL_FACE);
+    glEnable (GL_CULL_FACE);
 
     glGetFloatv (GL_COLOR_CLEAR_VALUE, background);
     glColor3fv (background);
@@ -483,9 +505,9 @@ if (group->loops != NULL)
   glDisable (GL_POLYGON_OFFSET_FILL);
   glLineWidth (1.0);
   glPointSize (1.0);
-  }
 
-glPopMatrix ();
+  glPopMatrix ();
+  }
 
 /* draw group list */
 dlist = group->group_start;
@@ -587,24 +609,45 @@ void gamgi_mesa_draw_cluster (gamgi_cluster *cluster)
 gamgi_dlist *dlist;
 double rotate[16];
 float background[4];
+double origin[3];
 
 glPushMatrix ();
 
-glTranslatef (cluster->center[0], cluster->center[1], cluster->center[2]);
-glScalef (cluster->object.scale, cluster->object.scale, cluster->object.scale);
-glTranslatef (-cluster->center[0], -cluster->center[1], -cluster->center[2]);
-
-glPushMatrix ();
-
-glTranslatef (cluster->origin[0], cluster->origin[1], cluster->origin[2]);
-
-gamgi_math_quaternion_to_matrix4 (cluster->quaternion, rotate);
-glMultMatrixd (rotate);
-
-if (cluster->loops != NULL)
+if (cluster->loops == NULL)
   {
-  glLineWidth (GAMGI_MESA_CLUSTER_WIDTH);
-  glPointSize (GAMGI_MESA_CLUSTER_WIDTH);
+  /*****************************************************
+   * this contains other objects only, such as atoms:  *
+   * scale to layer center, otherwise changing an atom *
+   * would change the cluster center, in turn changing *
+   * the aparent position of all the other atoms       *
+   *****************************************************/
+
+  gamgi_math_vector_absolute (origin, 0.0, 0.0, 0.0);
+
+  glTranslatef (origin[0], origin[1], origin[2]);
+  glScalef (cluster->object.scale, cluster->object.scale, cluster->object.scale);
+  glTranslatef (-origin[0], -origin[1], -origin[2]);
+  }
+else
+  {
+  /************************************************
+   * this cluster is a polytope: change according *
+   * to cluster center, origin and quaternion     *
+   ************************************************/
+
+  glTranslatef (cluster->center[0], cluster->center[1], cluster->center[2]);
+  glScalef (cluster->object.scale, cluster->object.scale, cluster->object.scale);
+  glTranslatef (-cluster->center[0], -cluster->center[1], -cluster->center[2]);
+
+  glPushMatrix ();
+
+  glTranslatef (cluster->origin[0], cluster->origin[1], cluster->origin[2]);
+
+  gamgi_math_quaternion_to_matrix4 (cluster->quaternion, rotate);
+  glMultMatrixd (rotate);
+  
+  glLineWidth (GAMGI_MESA_POLYHEDRON_WIDTH);
+  glPointSize (GAMGI_MESA_POLYHEDRON_WIDTH);
 
   if (cluster->faces == TRUE)
     {
@@ -626,15 +669,15 @@ if (cluster->loops != NULL)
 
   gamgi_mesa_render_loops (cluster->loops, cluster->points);
 
-  if (cluster->seeds == TRUE)
-    gamgi_mesa_render_points (cluster->n_seeds, cluster->points);
+  if (cluster->dots == TRUE)
+    gamgi_mesa_render_points (cluster->n_dots, cluster->points);
 
   glDisable (GL_POLYGON_OFFSET_FILL);
   glLineWidth (1.0);
   glPointSize (1.0);
-  }
 
-glPopMatrix ();
+  glPopMatrix ();
+  }
 
 /* draw cluster list */
 dlist = cluster->cluster_start;
@@ -1019,7 +1062,7 @@ layer->up[0], layer->up[1], layer->up[2]);
  * if they were not enabled *
  ****************************/
 
-for (light = 0; light < gamgi->lights; light++) glDisable (GL_LIGHT0 + light);
+for (light = 0; light < gamgi->max_lights; light++) glDisable (GL_LIGHT0 + light);
 
 light = 0;
 if ((dlist = layer->light_start) != NULL)
@@ -1224,7 +1267,7 @@ if (window->layer->visibility_out != GAMGI_GTK_NONE)
   glEnable (GL_BLEND);
   glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
   glColor4f (window->layer->color[0], window->layer->color[1],
-  window->layer->color[2], GAMGI_MESA_LAYER_BLENDING);
+  window->layer->color[2], GAMGI_MESA_LAYER_BLEND);
   
   glClear (GL_DEPTH_BUFFER_BIT);
   x = window->area->allocation.width;
@@ -1263,6 +1306,12 @@ if (window->layer->visibility_out != GAMGI_GTK_NONE)
  *****************************/
 
 gamgi_mesa_draw_layer (window->layer, window);
+
+/************************************
+ * fourth, draw selection rectangle *
+ ************************************/
+
+gamgi_mesa_select_draw (window);
 }
 
 void gamgi_mesa_draw_gamgi (void) 
