@@ -10,6 +10,7 @@
  */
 
 #include "gamgi_engine.h"
+#include "gamgi_mesa.h"
 #include "gamgi_gtk.h"
 #include "gamgi_global.h"
 
@@ -50,6 +51,7 @@
 #include "gamgi_gtk_group_copy.h"
 #include "gamgi_gtk_group_select.h"
 #include "gamgi_gtk_group_link.h"
+#include "gamgi_gtk_group_create.h"
 #include "gamgi_gtk_group_modify.h"
 #include "gamgi_gtk_group_measure.h"
 #include "gamgi_gtk_group_remove.h"
@@ -89,7 +91,8 @@
 #include "gamgi_gtk_window_link.h"
 #include "gamgi_gtk_window_remove.h"
 #include "gamgi_mesa_area.h"
-#include "gamgi_mesa_scan.h"
+#include "gamgi_mesa_pick.h"
+#include "gamgi_mesa_grab.h"
 
 static void static_select (gamgi_object *object, void *data)
 {
@@ -134,13 +137,37 @@ slist->data = GAMGI_INT_TO_POINTER (color_new);
 return slist;
 }
 
-static gamgi_slist *static_pixel (int x, int y)
+static void static_start (void)
+{
+unsigned char off[3] = {0, 0, 0};
+
+/********************************
+ * switch off colors and lights *
+ ********************************/
+
+glClearColor (0.0, 0.0, 0.0, 1.0);
+glClear (GL_COLOR_BUFFER_BIT);
+glColor3ubv (off);
+glDisable (GL_LIGHTING);
+glDisable (GL_NORMALIZE);
+glDisable (GL_DITHER);
+
+/**********************
+ * reset object color *
+ **********************/
+
+gamgi->rgb[0] = 0; gamgi->rgb[1] = 0; gamgi->rgb[2] = 0;
+}
+
+static gamgi_slist *static_pick_pixels (int x, int y)
 {
 int i, color, n = gamgi->gamgi->tolerance;
-int pixels = pow (2*n + 1, 2);
+int pixels;
 unsigned char *rgb;
 gamgi_slist *slist = NULL;
-int r1, r0, g1, g0, b1, b0;
+int r0, r1, g0, g1, b0, b1;
+
+pixels = pow (2*n + 1, 2);
 
 /*****************************************************
  * gamgi->r, gamgi->g, gamgi->b represent the number *
@@ -161,7 +188,7 @@ b1 = pow (2, 8 - gamgi->b);
  * lower-left corner (x-n, y-n) to the upper-right corner (x+n, y+n) *
  *********************************************************************/
 
-rgb = gamgi_mesa_area_grab (x-n, y-n, 2*n+1, 2*n+1);
+rgb = gamgi_mesa_area_read (x-n, y-n, 2*n+1, 2*n+1);
 
 i = 0;
 do
@@ -198,42 +225,92 @@ free (rgb);
 return slist;
 }
 
-static void static_start (void)
+static gamgi_slist *static_grab_pixels (int x, int y, int width, int height,
+gamgi_object **objects, int *levels, int level, gamgi_slist *slist)
 {
-unsigned char off[3] = {0, 0, 0};
+int i, color;
+int pixels;
+unsigned char *rgb;
+int r0, r1, g0, g1, b0, b1;
 
-/********************************
- * switch off colors and lights *
- ********************************/
+pixels = width * height;
 
-glClearColor (0.0, 0.0, 0.0, 1.0);
-glClear (GL_COLOR_BUFFER_BIT);
-glColor3ubv (off);
-glDisable (GL_LIGHTING);
-glDisable (GL_NORMALIZE);
-glDisable (GL_DITHER);
-  
-/**********************
- * reset object color *
- **********************/
+/*****************************************************
+ * gamgi->r, gamgi->g, gamgi->b represent the number *
+ * of missing bits when compared with 8 (True Color) *
+ *****************************************************/
 
-gamgi->rgb[0] = 0; gamgi->rgb[1] = 0; gamgi->rgb[2] = 0;
+r0 = pow (2, gamgi->r);
+r1 = pow (2, 8 - gamgi->r);
+
+g0 = pow (2, gamgi->g);
+g1 = pow (2, 8 - gamgi->g);
+
+b0 = pow (2, gamgi->b);
+b1 = pow (2, 8 - gamgi->b);
+
+/***********************************************************************
+ * grab colors for all width height pixels in the rectangle going from *
+ * the lower-left corner (x0, y0) to the upper-right corner (x1, y1)   *
+ ***********************************************************************/
+
+rgb = gamgi_mesa_area_read (x, y, width, height);
+
+i = 0;
+do
+  {
+  /**********************************************************
+   * shift color bits to the right and then to the left,    *
+   * to replace undefined bits by zeros. For example,       *
+   * in a graphic system running 16 color bits per pixel,   *
+   * distributed as 5 6 5, [rrrrr???] [gggggg??] [bbbbb???] *
+   * would be replaced by [rrrrr000] [gggggg00] [bbbbb000]  *
+   **********************************************************/
+
+  rgb[i] = (rgb[i] >> gamgi->r) << gamgi->r;
+  rgb[i+1] = (rgb[i+1] >> gamgi->g) << gamgi->g;
+  rgb[i+2] = (rgb[i+2] >> gamgi->b) << gamgi->b;
+
+  /**********************************************************************
+   * r1,g1,b1 represent the number of color sequences recognized by     *
+   * the graphic system. When scanning objects, b changes faster (less  *
+   * important channel), then g, and finally r (more important channel) *
+   *                                                                    *
+   * r0,g0,b0 represent the number of sequences that become equal       *
+   * for each channel, as the lower bits are ignored, so to get the     *
+   * number of real colors scanned we have to divide by r0,g0,b0        *
+   **********************************************************************/
+
+  color = b1 * g1 * rgb[3*i]/r0 + b1 * rgb[3*i+1]/g0 + rgb[3*i+2]/b0;
+
+  if (color == 0 || levels[color - 1] == level) continue;
+
+  levels[color - 1] = level; 
+  slist = gamgi_engine_slist_add_start (slist);
+  slist->data = objects[color - 1];
+  }
+  while (++i < pixels);
+
+free (rgb);
+
+return slist;
 }
 
-static gamgi_object *static_object (gamgi_window *window, 
-int x, int y, int class, gamgi_bool global)
+static gamgi_object *static_pick_objects (int x, int y, int class,
+gamgi_bool global, gamgi_window *window)
 {
 GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable (window->area);
 GdkGLContext *glcontext = gtk_widget_get_gl_context (window->area);
-gamgi_object **array;
+gamgi_object **objects;
 gamgi_object *object;
 gamgi_slist *slist;
-int index, number = 0;
+int index, number;
 
 /*************************************
  * count number of candidate objects *
  *************************************/
 
+number = 0;
 if (global == TRUE)
   gamgi_engine_count_window (window, class, &number);
 else
@@ -244,22 +321,22 @@ if (number == 0) return NULL;
  * allocate array to store candidate objects addresses *
  *******************************************************/
 
-array = (gamgi_object **) malloc (number * sizeof (object));
-if (array == NULL) return NULL;
+objects = (gamgi_object **) malloc (number * sizeof (object));
+if (objects == NULL) return NULL;
 
-/*********************************************************
- * draw candidate objects in back buffer, each one with  *
- * a different color, and store their addresses in array *
- *********************************************************/
+/**********************************************************
+ * draw candidate objects in back buffer, each one with a *
+ * different color, and store their addresses in objects  *
+ **********************************************************/
 
 if (gdk_gl_drawable_gl_begin (gldrawable, glcontext) == TRUE)
   {
   static_start ();
 
   if (global == TRUE)
-    gamgi_mesa_scan_window (window, class, array);
+    gamgi_mesa_pick_window (window, class, objects);
   else
-    gamgi_mesa_scan_layer (window->layer, window, class, array);
+    gamgi_mesa_pick_layer (window->layer, window, class, objects);
 
   gdk_gl_drawable_gl_end (gldrawable);
   }
@@ -273,24 +350,106 @@ if (gdk_gl_drawable_gl_begin (gldrawable, glcontext) == TRUE)
  *        or more than one has been found       *
  ************************************************/
 
-slist = static_pixel (x, y);
+slist = static_pick_pixels (x, y);
 if (slist == NULL || slist->next != NULL) object = NULL;
 else
   {
   index = GAMGI_POINTER_TO_INT (slist->data);
-  object = GAMGI_CAST_OBJECT array[index - 1];
+  object = GAMGI_CAST_OBJECT objects[index - 1];
   }
 
 /******************
  * free resources *
  ******************/
 
-free (array);
+free (objects);
 gamgi_engine_slist_remove_all (slist);
 
 return object;
 }
 
+gamgi_slist *static_grab_objects (int *box, gamgi_enum class,
+gamgi_window *window)
+{
+GdkGLDrawable *gldrawable = gtk_widget_get_gl_drawable (window->area);
+GdkGLContext *glcontext = gtk_widget_get_gl_context (window->area);
+gamgi_object **objects;
+int *levels;
+int width, height;
+gamgi_object *object;
+gamgi_slist *slist_old, *slist_new;
+int number;
+int level;
+
+/*************************************
+ * count number of candidate objects *
+ *************************************/
+
+number = 0;
+gamgi_engine_count_window (window, class, &number);
+if (number == 0) return NULL;
+
+/*******************************************************
+ * allocate array to store candidate objects addresses *
+ *******************************************************/
+
+objects = (gamgi_object **) malloc (number * sizeof (object));
+if (objects == NULL) return NULL;
+
+levels = (int *) calloc (number, sizeof (int));
+if (levels == NULL) return NULL;
+
+/***********************************************
+ * render objects sucessively until no more    *
+ * objects can be found in selection rectangle *
+ ***********************************************/
+
+width = box[2] - box[0] + 1;
+height = box[3] - box[1] + 1;
+slist_new = NULL;
+level = 0;
+
+do
+  {
+  level++;
+  slist_old = slist_new;
+
+  /***********************************************************
+   * 3D code: draw candidate objects in back buffer, each    *
+   * one with a different color, store their addresses in    *
+   * objects and the scans when they were selected in levels *
+   *                                                         *
+   * when an object is selected, it stops being rendered, so *
+   * objects hidden below can be selected in the next scans  *
+   ***********************************************************/
+         
+  if (gdk_gl_drawable_gl_begin (gldrawable, glcontext) == TRUE)
+    {      
+    static_start ();
+    gamgi_mesa_grab_window (window, class, level, -1, objects, levels);
+    gdk_gl_drawable_gl_end (gldrawable);
+    }
+
+  /***********************************************************
+   * 2D code: read the selection rectangle and analyse each  *
+   * pixel to find all the rendered objects inside. Build    *
+   * a list with all the objects found in the various scans. *
+   ***********************************************************/
+
+  slist_new = static_grab_pixels (box[0], box[1],
+  width, height, objects, levels, level, slist_old);
+  } while (slist_new != slist_old);
+
+/******************
+ * free resources *
+ ******************/
+
+free (objects);
+free (levels);
+
+return slist_new;
+}
+
 static void static_activate (GtkWidget *widget, void *data)
 {
 gamgi_object *object;
@@ -311,9 +470,9 @@ item = gtk_menu_item_new_with_label (string);
 g_object_set_data (G_OBJECT (item), "object", object);
 
 if (menu == NULL) menu = gtk_menu_new ();
-gtk_menu_append (GTK_MENU (menu), item);
+gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-g_signal_connect (GTK_OBJECT (item), "activate",
+g_signal_connect (item, "activate",
 G_CALLBACK (static_activate), window);
 gtk_widget_show (item);
 
@@ -380,13 +539,13 @@ if (menu != NULL)
   gtk_menu_popup ((GtkMenu *) menu, NULL, NULL, NULL, NULL, 1, 0);
 }
 
-static void static_recursive (gamgi_window *window,
-int x, int y, int class, gamgi_bool global)
+static void static_recursive (int x, int y, int class, gamgi_bool global,
+gamgi_window *window)
 {
 gamgi_object *object;
 GtkWidget *menu = NULL;
 
-object = static_object (window, x, y, class, global);
+object = static_pick_objects (x, y, class, global, window);
 if (object == NULL) return;
 
 if (object->object->class != class)
@@ -421,7 +580,8 @@ for (window = gamgi->window_start; window != NULL; window = window->next)
 return NULL;
 }
 
-gamgi_bool gamgi_mesa_select_action (gamgi_window *window_mouse, int x, int y)
+gamgi_bool gamgi_mesa_select_action (gamgi_window *window_mouse,
+GdkEventButton *event, int x, int y)
 {
 gamgi_window *window_dialog;
 
@@ -440,287 +600,291 @@ switch (window_dialog->action)
    ******************************************************/
 
   case GAMGI_GTK_TEXT_CREATE:
-  gamgi_gtk_text_create_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_text_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_TEXT_COPY:
-  gamgi_gtk_text_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_text_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_TEXT_SELECT:
-  gamgi_gtk_text_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_text_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_TEXT_LINK:
-  gamgi_gtk_text_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_text_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_TEXT_MODIFY:
-  gamgi_gtk_text_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_text_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_TEXT_REMOVE:
-  gamgi_gtk_text_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_text_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_BOND_CREATE:
-  gamgi_gtk_bond_create_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_bond_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_BOND_SELECT:
-  gamgi_gtk_bond_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_bond_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_BOND_LINK:
-  gamgi_gtk_bond_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_bond_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_BOND_MODIFY:
-  gamgi_gtk_bond_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_bond_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_BOND_REMOVE:
-  gamgi_gtk_bond_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_bond_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ATOM_CREATE:
-  gamgi_gtk_atom_create_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_atom_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ATOM_COPY:
-  gamgi_gtk_atom_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_atom_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ATOM_SELECT:
-  gamgi_gtk_atom_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_atom_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ATOM_LINK:
-  gamgi_gtk_atom_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_atom_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ATOM_MODIFY:
-  gamgi_gtk_atom_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_atom_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ATOM_MEASURE:
-  gamgi_gtk_atom_measure_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_atom_measure_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ATOM_REMOVE:
-  gamgi_gtk_atom_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_atom_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_DIRECTION_CREATE:
-  gamgi_gtk_direction_create_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_direction_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_DIRECTION_SELECT:
-  gamgi_gtk_direction_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_direction_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_DIRECTION_LINK:
-  gamgi_gtk_direction_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_direction_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_DIRECTION_MODIFY:
-  gamgi_gtk_direction_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_direction_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_DIRECTION_MEASURE:
-  gamgi_gtk_direction_measure_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_direction_measure_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_DIRECTION_REMOVE:
-  gamgi_gtk_direction_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_direction_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_PLANE_CREATE:
-  gamgi_gtk_plane_create_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_plane_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_PLANE_SELECT:
-  gamgi_gtk_plane_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_plane_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_PLANE_LINK:
-  gamgi_gtk_plane_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_plane_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_PLANE_MODIFY:
-  gamgi_gtk_plane_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_plane_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_PLANE_MEASURE:
-  gamgi_gtk_plane_measure_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_plane_measure_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_PLANE_REMOVE:
-  gamgi_gtk_plane_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_plane_remove_press (window_mouse, event, x, y, window_dialog);
+  return TRUE;
+
+  case GAMGI_GTK_GROUP_CREATE:
+  gamgi_gtk_group_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_GROUP_COPY:
-  gamgi_gtk_group_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_group_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_GROUP_SELECT:
-  gamgi_gtk_group_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_group_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_GROUP_LINK:
-  gamgi_gtk_group_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_group_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_GROUP_MODIFY:
-  gamgi_gtk_group_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_group_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_GROUP_MEASURE:
-  gamgi_gtk_group_measure_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_group_measure_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_GROUP_REMOVE:
-  gamgi_gtk_group_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_group_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_MOLECULE_COPY:
-  gamgi_gtk_molecule_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_molecule_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_MOLECULE_SELECT:
-  gamgi_gtk_molecule_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_molecule_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_MOLECULE_LINK:
-  gamgi_gtk_molecule_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_molecule_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_MOLECULE_MEASURE:
-  gamgi_gtk_molecule_measure_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_molecule_measure_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_MOLECULE_REMOVE:
-  gamgi_gtk_molecule_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_molecule_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CLUSTER_COPY:
-  gamgi_gtk_cluster_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cluster_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CLUSTER_SELECT:
-  gamgi_gtk_cluster_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cluster_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CLUSTER_LINK:
-  gamgi_gtk_cluster_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cluster_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CLUSTER_MEASURE:
-  gamgi_gtk_cluster_measure_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cluster_measure_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CLUSTER_REMOVE:
-  gamgi_gtk_cluster_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cluster_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CELL_CREATE:
-  gamgi_gtk_cell_create_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cell_create_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CELL_COPY:
-  gamgi_gtk_cell_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cell_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CELL_SELECT:
-  gamgi_gtk_cell_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cell_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CELL_MODIFY:
-  gamgi_gtk_cell_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cell_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE; 
 
   case GAMGI_GTK_CELL_LINK:
-  gamgi_gtk_cell_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cell_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CELL_MEASURE:
-  gamgi_gtk_cell_measure_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cell_measure_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_CELL_REMOVE:
-  gamgi_gtk_cell_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_cell_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ASSEMBLY_COPY:
-  gamgi_gtk_assembly_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_assembly_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ASSEMBLY_SELECT:
-  gamgi_gtk_assembly_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_assembly_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ASSEMBLY_LINK:
-  gamgi_gtk_assembly_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_assembly_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_ASSEMBLY_REMOVE:
-  gamgi_gtk_assembly_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_assembly_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LIGHT_COPY:
-  gamgi_gtk_light_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_light_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LIGHT_SELECT:
-  gamgi_gtk_light_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_light_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LIGHT_LINK:
-  gamgi_gtk_light_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_light_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LIGHT_MODIFY:
-  gamgi_gtk_light_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_light_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LIGHT_REMOVE:
-  gamgi_gtk_light_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_light_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LAYER_COPY:
-  gamgi_gtk_layer_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_layer_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LAYER_SELECT:
-  gamgi_gtk_layer_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_layer_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LAYER_LINK:
-  gamgi_gtk_layer_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_layer_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LAYER_MODIFY:
-  gamgi_gtk_layer_modify_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_layer_modify_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_LAYER_REMOVE:
-  gamgi_gtk_layer_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_layer_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_WINDOW_COPY:
-  gamgi_gtk_window_copy_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_window_copy_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_WINDOW_SELECT:
-  gamgi_gtk_window_select_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_window_select_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_WINDOW_LINK:
-  gamgi_gtk_window_link_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_window_link_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
 
   case GAMGI_GTK_WINDOW_REMOVE:
-  gamgi_gtk_window_remove_press (window_mouse, x, y, window_dialog);
+  gamgi_gtk_window_remove_press (window_mouse, event, x, y, window_dialog);
   return TRUE;
   }
 
@@ -819,11 +983,11 @@ switch (class)
   
   case GAMGI_ENGINE_ASSEMBLY: case GAMGI_ENGINE_CLUSTER:
   case GAMGI_ENGINE_GROUP: case GAMGI_ENGINE_TEXT:
-  static_recursive (window, x, y, class, global);
+  static_recursive (x, y, class, global, window);
   break;
 
   default:
-  object = static_object (window, x, y, class, global);
+  object = static_pick_objects (x, y, class, global, window);
   if (object != NULL) static_apply (object, window);
   break;
   }
@@ -832,5 +996,289 @@ switch (class)
  * reset object selection *
  **************************/
 
-window->selection = FALSE;
+window->class = FALSE;
+}
+
+gamgi_slist *gamgi_mesa_select_region (int *box, gamgi_enum class,
+gamgi_window *window_mouse, gamgi_window *window_dialog)
+{
+gamgi_slist *slist;
+
+/**********************************************************************
+ * objects without visual representation cannot be selected by region *
+ **********************************************************************/
+
+if (class == GAMGI_ENGINE_GAMGI || class == GAMGI_ENGINE_WINDOW ||
+class == GAMGI_ENGINE_LAYER || class == GAMGI_ENGINE_LIGHT) return NULL;
+
+/********************************************************
+ * grab objects in selected rectangle that are in scope *
+ ********************************************************/
+
+slist = static_grab_objects (box, class, window_mouse);
+
+return slist;
+}
+
+void gamgi_mesa_select_reset (gamgi_window *window)
+{
+gamgi->state = FALSE;
+if (gamgi->window_mouse != NULL)
+  {
+  gtk_widget_queue_draw (gamgi->window_mouse->area);
+  gamgi->window_mouse = NULL;
+  }
+}
+
+void gamgi_mesa_select_state (char *name, gamgi_window *window)
+{
+if (strcmp (name, "Region") == 0)
+  gamgi->state = GAMGI_MESA_SELECT_READY;
+else
+  gamgi_mesa_select_reset (window);
+}
+
+void gamgi_mesa_select_draw (gamgi_window *window)
+{
+float *color = window->layer->color;
+int *box = gamgi->box;
+int width = window->area->allocation.width;
+int height = window->area->allocation.height;
+int square = GAMGI_MESA_SELECT_SQUARE;
+
+if (window != gamgi->window_mouse) return;
+
+/*************************************
+ * box format: state, x0, y0, x1, y1 *
+ *************************************/
+
+if (gamgi->state < GAMGI_MESA_SELECT_SIZE) return;
+
+/**************************************************
+ * equivalent to gluOrtho2D (0, width, 0, height) *
+ **************************************************/
+
+glMatrixMode (GL_PROJECTION);
+glLoadIdentity ();
+glOrtho (0, width, 0, height, -1, +1);
+
+/************************
+ * restart depth buffer *
+ ************************/
+
+glMatrixMode (GL_MODELVIEW);
+glLoadIdentity ();
+glClear (GL_DEPTH_BUFFER_BIT);
+
+/**************************************************
+ * use a color that is visible, over the current  *
+ * background color, defined by the current layer *
+ **************************************************/
+
+if (color[0] + color[0] + color[0] > 1.5)
+  glColor3f (0.0, 0.0, 0.0);
+else
+  glColor3f (1.0, 1.0, 1.0);
+
+/************************************************************************
+ * To get accurate 2D pixel rendering, OpenGL polygons such those built *
+ * with GL_POLYGON and glRecti should be rendered between initial pixel *
+ * and final pixel plus 1 (the box borders), while point and line       *
+ * constructions such those built with GL_LINE_LOOP should be rendered  *
+ * adding 0.5 to each pixel (to define exactly the center of the pixel) *
+ *                                                                      *
+ * A simpler alternative, suggested by the OpenGL Programming Guide     *
+ * (the red book), Release 1, 1993, pg. 482 (OpenGL correctness Tips),  *
+ * is to translate initially (0.375, 0.375, 0.0), and then add both     *
+ * polygons and lines always with their natural integer coordinates     *
+ *                                                                      *
+ * Use 1.0 (a float) default line width to better get 2D pixel accuracy *
+ ************************************************************************/
+
+glTranslatef (0.375, 0.375, 0.0);
+glLineWidth (1.0);
+
+/**************************
+ * draw the selection box *
+ **************************/
+
+glBegin (GL_LINE_LOOP);
+glVertex2i (box[0], box[1]);
+glVertex2i (box[2], box[1]);
+glVertex2i (box[2], box[3]);
+glVertex2i (box[0], box[3]);
+glEnd ();
+
+if (gamgi->state < GAMGI_MESA_SELECT_DONE) return;
+
+/************************
+ * draw the move square *
+ ************************/
+
+glRecti (box[0], box[3] - square + 1, box[0] + square, box[3] + 1);
+
+/**************************
+ * draw the resize square *
+ **************************/
+
+glBegin (GL_LINE_LOOP);
+glVertex2i (box[2] - square + 1, box[1]);
+glVertex2i (box[2], box[1]);
+glVertex2i (box[2], box[1] + square - 1);
+glVertex2i (box[2] - square + 1, box[1] + square - 1);
+glEnd ();
+
+/**********************************************
+ * blend everything outside the selection box *
+ **********************************************/
+
+glEnable (GL_BLEND);
+glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+glColor4f (color[0], color[1], color[2], GAMGI_MESA_SELECT_BLEND);
+
+glBegin (GL_POLYGON);
+glVertex2i (0, 0);
+glVertex2i (width, 0);
+glVertex2i (width, box[1]);
+glVertex2i (0, box[1]);
+glEnd ();
+
+glBegin (GL_POLYGON);
+glVertex2i (0, box[3] + 1);
+glVertex2i (width, box[3] + 1);
+glVertex2i (width, height);
+glVertex2i (0, height);
+glEnd ();
+
+glBegin (GL_POLYGON);
+glVertex2i (0, box[1]);
+glVertex2i (box[0], box[1]);
+glVertex2i (box[0], box[3] + 1);
+glVertex2i (0, box[3] + 1);
+glEnd ();
+
+glBegin (GL_POLYGON);
+glVertex2i (box[2] + 1, box[1]);
+glVertex2i (width, box[1]);
+glVertex2i (width, box[3] + 1);
+glVertex2i (box[2] + 1, box[3] + 1);
+glEnd ();
+
+glDisable (GL_BLEND);
+}
+
+void gamgi_mesa_select_press (int x, int y, gamgi_window *window)
+{
+int *box = gamgi->box;
+int square = GAMGI_MESA_SELECT_SQUARE;
+
+if (gamgi->state == GAMGI_MESA_SELECT_READY)
+  {
+  gamgi->window_mouse = window;
+  gamgi->state = GAMGI_MESA_SELECT_SIZE;
+  box[0] = box[2] = x;
+  box[1] = box[3] = y;
+  }
+
+else if (gamgi->state == GAMGI_MESA_SELECT_DONE)
+  {
+  if (window != gamgi->window_mouse)
+    {
+    gamgi->state = GAMGI_MESA_SELECT_READY;
+    gtk_widget_queue_draw (gamgi->window_mouse->area);
+    gamgi_mesa_select_press (x, y, window);
+    }
+
+  else if ((x >= box[0] && x <= box[0] + square - 1) &&
+  (y >= box[3] - square + 1 && y <= box[3]))
+    {
+    gamgi->state = GAMGI_MESA_SELECT_MOVE;
+    }
+
+  else if ((x >= box[2] - square + 1 && x <= box[2]) &&
+  (y >= box[1] && y <= box[1] + square - 1))
+    {
+    gamgi->state = GAMGI_MESA_SELECT_RESIZE;
+    }
+
+  else
+    {
+    gamgi->state = GAMGI_MESA_SELECT_READY;
+    gtk_widget_queue_draw (gamgi->window_mouse->area);
+    gamgi_mesa_select_press (x, y, window);
+    }
+  }
+}
+
+void gamgi_mesa_select_release (int x, int y, gamgi_window *window)
+{
+int *box = gamgi->box;
+int square = GAMGI_MESA_SELECT_SQUARE;
+int swap;
+
+if (gamgi->state == GAMGI_MESA_SELECT_SIZE ||
+gamgi->state == GAMGI_MESA_SELECT_MOVE ||
+gamgi->state == GAMGI_MESA_SELECT_RESIZE)
+  gamgi->state = GAMGI_MESA_SELECT_DONE;
+
+/*******************************************************************
+ * swap coordinates if necessary: box[0],box[1] should contain the *
+ * lower left corner, and box[2],box[3] the higher right corner    *
+ *******************************************************************/
+
+if (box[2] < box[0])
+  { swap = box[0]; box[0] = box[2]; box[2] = swap; }
+if (box[3] < box[1])
+  { swap = box[1]; box[1] = box[3]; box[3] = swap; }
+
+/**************************************************
+ * set minimum dimensions for selection rectangle *
+ **************************************************/
+
+if (box[2] < box[0] + 2 * square - 1)
+  box[2] = box[0] + 2 * square - 1;
+if (box[3] < box[1] + 2 * square - 1)
+  box[3] = box[1] + 2 * square - 1;
+
+gtk_widget_queue_draw (window->area);
+}
+
+void gamgi_mesa_select_notify (int x, int y, gamgi_window *window)
+{
+int *box = gamgi->box;
+int height = window->area->allocation.height;
+int square = GAMGI_MESA_SELECT_SQUARE;
+int dx, dy;
+
+if (gamgi->state == GAMGI_MESA_SELECT_SIZE)
+  {
+  box[2] = x;
+  box[3] = y;
+  }
+
+else if (gamgi->state == GAMGI_MESA_SELECT_MOVE)
+  {
+  dx = x - window->begin_x;
+  box[0] += dx;
+  box[2] += dx;
+
+  dy = y - (height - window->begin_y);
+  box[1] += dy;
+  box[3] += dy;
+  }
+
+else if (gamgi->state == GAMGI_MESA_SELECT_RESIZE)
+  {
+  dx = x - window->begin_x;
+  box[2] += dx;
+  if (box[2] < box[0] + 2 * square - 1)
+    box[2] = box[0] + 2 * square - 1;
+
+  dy = y - (height - window->begin_y);
+  box[1] += dy;
+  if (box[1] > box[3] - 2 * square + 1)
+    box[1] = box[3] - 2 * square + 1;
+  }
+
+gtk_widget_queue_draw (window->area);
 }
