@@ -15,6 +15,8 @@
 
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_phys_symmetry.h"
+#include "gamgi_math_vector.h"
+#include "gamgi_math_cell.h"
 
 static void static_range (const int *driver, int site, int *start, int *end)
 {
@@ -106,35 +108,56 @@ for (i = 0; i < n_positions; i++)
   {
   strcpy (token, wyckoff[start + i]);
 
-  /*******************************************
-   * apply translation symmetry so all       *
-   * coordinates are in the range [0.0, 1.0[ *
-   *******************************************/
+  /**********************************************
+   * parse wyckoff string to get cell positions *
+   **********************************************/
 
   token_a = strtok (token, ",");
   positions[0] = static_parser (token_a, input);
-  if (positions[0] < 0.0) positions[0]++;
-  if (positions[0] >= 1.0) positions[0]--;
-
   token_b = strtok (NULL, ",");
   positions[1] = static_parser (token_b, input);
-  if (positions[1] < 0.0) positions[1]++;
-  if (positions[1] >= 1.0) positions[1]--;
-
   token_c = strtok (NULL, ",");
   positions[2] = static_parser (token_c, input);
-  if (positions[2] < 0.0) positions[2]++;
-  if (positions[2] >= 1.0) positions[2]--;
+
+  /****************************************************
+   * make sure positions are in the range ]-1.0, 1.0[ *
+   ****************************************************/
+
+  gamgi_math_vector_fmod (positions, positions);
 
   positions += 3;
   }
 
 }
 
+static gamgi_bool static_equal (double *position_i, double *position_j)
+{
+double r[3], s[3];
+double x, y, z;
+
+gamgi_math_cell_range_positive (position_i, r);
+gamgi_math_cell_range_positive (position_j, s);
+
+x = fabs (r[0] - s[0]);
+y = fabs (r[1] - s[1]);
+z = fabs (r[2] - s[2]);
+
+/**********************************************************
+ * take translation symmetry into account when comparing  *
+ * positions: r,s coordinates are in the range ]0.0, 1.0[ *
+ **********************************************************/
+
+if ((x < GAMGI_PHYS_WYCKOFF_TOLERANCE || x > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE)
+&& (y < GAMGI_PHYS_WYCKOFF_TOLERANCE || y > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE)
+&& (z < GAMGI_PHYS_WYCKOFF_TOLERANCE || z > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE))
+  return TRUE;
+
+return FALSE;
+}
+
 static void static_compare_one (int n_positions, 
 double *positions, gamgi_bool *equal)
 {
-double x, y, z;
 int i, j;
 
 /*******************************************
@@ -152,18 +175,7 @@ for (i = 1; i < n_positions; i++)
   {
   for (j = 0; j < i; j++)
     {
-    x = fabs (positions[3*i + 0] - positions[3*j + 0]);
-    y = fabs (positions[3*i + 1] - positions[3*j + 1]);
-    z = fabs (positions[3*i + 2] - positions[3*j + 2]);
-
-    /*********************************************************** 
-     * take translation symmetry into account when comparing   *
-     * positions: all coordinates are in the range ]-1.0, 1.0[ *
-     ***********************************************************/
-    
-    if ((x < GAMGI_PHYS_WYCKOFF_TOLERANCE || x > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE)
-    && (y < GAMGI_PHYS_WYCKOFF_TOLERANCE || y > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE)
-    && (z < GAMGI_PHYS_WYCKOFF_TOLERANCE || z > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE))
+    if (static_equal (positions + 3*i, positions + 3*j) == TRUE)
       equal[i] = TRUE;
     }
   }
@@ -172,7 +184,6 @@ for (i = 1; i < n_positions; i++)
 static void static_compare_two (int n_positions, 
 double *positions, double *positions_new, gamgi_bool *equal)
 {
-double x, y, z;
 int i, j;
 
 /*******************************************
@@ -190,18 +201,7 @@ for (i = 0; i < n_positions; i++)
   {
   for (j = 0; j < n_positions; j++)
     {
-    x = fabs (positions[3*i + 0] - positions_new[3*j + 0]);
-    y = fabs (positions[3*i + 1] - positions_new[3*j + 1]);
-    z = fabs (positions[3*i + 2] - positions_new[3*j + 2]);
-
-    /***********************************************************
-     * take translation symmetry into account when comparing   * 
-     * positions: all coordinates are in the range ]-1.0, 1.0[ *
-     ***********************************************************/
-
-    if ((x < GAMGI_PHYS_WYCKOFF_TOLERANCE || x > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE)
-    && (y < GAMGI_PHYS_WYCKOFF_TOLERANCE || y > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE)
-    && (z < GAMGI_PHYS_WYCKOFF_TOLERANCE || z > 1.0 - GAMGI_PHYS_WYCKOFF_TOLERANCE)) 
+    if (static_equal (positions + 3*i, positions_new + 3*j) == TRUE)
       equal[i] = TRUE;
     }
   }
